static SYMBOL_TABLE: phf::Map<&'static str, Symbol> = ::phf::Map {
    key: 16287231350648472473,
    disps: &[
        (0, 242),
        (0, 9),
        (0, 66),
        (0, 436),
        (0, 20),
        (0, 91),
        (0, 0),
        (0, 7),
        (1, 84),
        (0, 253),
        (0, 44),
        (0, 199),
        (0, 53),
        (0, 3),
        (0, 1),
        (0, 305),
        (0, 972),
        (0, 15),
        (0, 2),
        (0, 7),
        (0, 23),
        (0, 124),
        (0, 29),
        (0, 29),
        (0, 0),
        (0, 2),
        (0, 3),
        (0, 275),
        (0, 37),
        (1, 300),
        (0, 2),
        (0, 27),
        (0, 22),
        (0, 11),
        (0, 43),
        (0, 6),
        (0, 611),
        (0, 122),
        (0, 76),
        (0, 2),
        (0, 1),
        (0, 0),
        (0, 499),
        (0, 29),
        (0, 10),
        (0, 23),
        (0, 3),
        (0, 369),
        (0, 55),
        (0, 868),
        (0, 147),
        (0, 436),
        (0, 98),
        (0, 9),
        (0, 62),
        (0, 53),
        (0, 808),
        (0, 5),
        (0, 20),
        (0, 52),
        (0, 311),
        (0, 785),
        (0, 1),
        (0, 8),
        (1, 966),
        (0, 28),
        (0, 767),
        (0, 4),
        (0, 0),
        (0, 673),
        (0, 129),
        (0, 44),
        (0, 11),
        (0, 277),
        (0, 1042),
        (0, 113),
        (0, 1),
        (0, 3),
        (0, 144),
        (0, 42),
        (0, 58),
        (0, 86),
        (0, 26),
        (0, 8),
        (0, 6),
        (0, 9),
        (0, 26),
        (0, 443),
        (0, 850),
        (0, 2),
        (0, 49),
        (0, 308),
        (0, 294),
        (0, 0),
        (0, 2),
        (0, 0),
        (0, 168),
        (0, 45),
        (0, 20),
        (0, 328),
        (0, 98),
        (0, 30),
        (0, 0),
        (0, 218),
        (0, 304),
        (0, 1113),
        (0, 619),
        (0, 175),
        (0, 23),
        (0, 528),
        (0, 378),
        (0, 112),
        (1, 545),
        (0, 368),
        (0, 139),
        (1, 38),
        (0, 684),
        (0, 600),
        (0, 372),
        (0, 441),
        (2, 373),
        (0, 11),
        (0, 38),
        (0, 0),
        (0, 4),
        (0, 4),
        (0, 13),
        (0, 0),
        (0, 359),
        (0, 125),
        (0, 14),
        (0, 301),
        (0, 61),
        (0, 85),
        (0, 543),
        (1, 403),
        (0, 883),
        (0, 323),
        (2, 126),
        (0, 88),
        (0, 422),
        (0, 0),
        (1, 398),
        (0, 9),
        (0, 5),
        (0, 80),
        (0, 0),
        (0, 46),
        (0, 110),
        (0, 0),
        (0, 4),
        (0, 38),
        (0, 28),
        (2, 340),
        (1, 49),
        (0, 41),
        (0, 37),
        (2, 828),
        (0, 878),
        (0, 558),
        (1, 519),
        (2, 394),
        (0, 822),
        (1, 259),
        (0, 1),
        (0, 800),
        (0, 196),
        (0, 8),
        (0, 219),
        (0, 4),
        (0, 43),
        (1, 325),
        (0, 31),
        (1, 326),
        (4, 124),
        (0, 192),
        (0, 904),
        (0, 1),
        (0, 111),
        (0, 291),
        (0, 3),
        (0, 0),
        (5, 733),
        (0, 4),
        (0, 507),
        (0, 737),
        (0, 0),
        (0, 970),
        (0, 25),
        (0, 0),
        (6, 242),
        (1, 2),
        (0, 0),
        (5, 747),
        (0, 17),
        (0, 554),
        (0, 1000),
        (8, 834),
        (0, 264),
        (3, 1028),
        (0, 230),
        (0, 619),
        (0, 11),
        (0, 3),
        (0, 442),
        (0, 426),
        (0, 853),
        (10, 70),
        (0, 0),
        (1, 480),
        (1, 510),
        (5, 417),
        (0, 123),
        (19, 198),
        (3, 869),
        (0, 5),
        (0, 897),
        (1, 53),
        (0, 478),
        (0, 17),
        (0, 62),
        (0, 406),
        (0, 54),
        (0, 81),
        (0, 80),
    ],
    entries: &[
        ("ZXNpbnQtT1QxLV9paWlpbnQ=", Symbol { command: "\\iiiint", package: "esint", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("integral.quad") }),
        ("dXBncmVlay1PVDEtX3VwdGhldGE=", Symbol { command: "\\uptheta", package: "upgreek", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX25ndHI=", Symbol { command: "\\ngtr", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("gt.not") }),
        ("dGlwYS1PVDEtX3RleHRjdGQ=", Symbol { command: "\\textctd", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX21hdGhmcmFre3V9", Symbol { command: "\\mathfrak{u}", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.frak(u)") }),
        ("YW1zc3ltYi1PVDEtX2d0cmFwcHJveA==", Symbol { command: "\\gtrapprox", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("gt.approx") }),
        ("YW1zc3ltYi1PVDEtX2Rvd25oYXJwb29ucmlnaHQ=", Symbol { command: "\\downharpoonright", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("harpoon.br") }),
        ("dGV4dGNvbXAtT1QxLV90ZXh0ZGl2", Symbol { command: "\\textdiv", package: "textcomp", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("bGF0ZXgyZS1PVDEtX25vdF9zaW0=", Symbol { command: "\\not\\sim", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: None }),
        ("bWFydm9zeW0tT1QxLV9QZnVuZA==", Symbol { command: "\\Pfund", package: "marvosym", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX21hdGhmcmFre0V9", Symbol { command: "\\mathfrak{E}", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.frak(E)") }),
        ("YW1zc3ltYi1PVDEtX21hdGhiYntOfQ==", Symbol { command: "\\mathbb{N}", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX21hdGhjYWx7RH0=", Symbol { command: "\\mathcal{D}", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.cal(D)") }),
        ("bWFydm9zeW0tT1QxLV9FVVJkaWc=", Symbol { command: "\\EURdig", package: "marvosym", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("ZHNmb250LU9UMS1fbWF0aGRze019", Symbol { command: "\\mathds{M}", package: "dsfont", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.bb(M)") }),
        ("d2FzeXN5bS1PVDEtX2FzdHJvc3Vu", Symbol { command: "\\astrosun", package: "wasysym", font_encoding: "OT1", text_mode: true, math_mode: true, typst_command: Some("sun") }),
        ("YW1zc3ltYi1PVDEtX25sZXFzbGFudA==", Symbol { command: "\\nleqslant", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: None }),
        ("dGlwYS1PVDEtX3RleHR1cHNpbG9u", Symbol { command: "\\textupsilon", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("dGV4dGNvbXAtT1QxLV90ZXh0cXVvdGVzaW5nbGU=", Symbol { command: "\\textquotesingle", package: "textcomp", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX25zdWJzZXRlcQ==", Symbol { command: "\\nsubseteq", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("subset.eq.not") }),
        ("dGlwYS1PVDEtX3RleHRjdGRjdHpsaWc=", Symbol { command: "\\textctdctzlig", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX21hdGhmcmFre3J9", Symbol { command: "\\mathfrak{r}", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.frak(r)") }),
        ("dGlwYS1PVDEtX3RleHR0dXJuaw==", Symbol { command: "\\textturnk", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("c3RtYXJ5cmQtT1QxLV9zaG9ydGxlZnRhcnJvdw==", Symbol { command: "\\shortleftarrow", package: "stmaryrd", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: None }),
        ("bGF0ZXgyZS1PVDEtX3RleHRlbmRhc2g=", Symbol { command: "\\textendash", package: "latex2e", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: Some("--") }),
        ("bGF0ZXgyZS1PVDEtX2JpZ290aW1lcw==", Symbol { command: "\\bigotimes", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("times.circle.big") }),
        ("dGV4dGNvbXAtT1QxLV90ZXh0b3JkZmVtaW5pbmU=", Symbol { command: "\\textordfeminine", package: "textcomp", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("bWF0aHJzZnMtT1QxLV9tYXRoc2Nye1F9", Symbol { command: "\\mathscr{Q}", package: "mathrsfs", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.scr(Q)") }),
        ("bGF0ZXgyZS1PVDEtX2lvdGE=", Symbol { command: "\\iota", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("iota") }),
        ("bGF0ZXgyZS1PVDEtX3RleHRiYXI=", Symbol { command: "\\textbar", package: "latex2e", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: Some("\\|") }),
        ("c3RtYXJ5cmQtT1QxLV9Mb25nbWFwc3Rv", Symbol { command: "\\Longmapsto", package: "stmaryrd", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("arrow.r.double.long.bar") }),
        ("YW1zc3ltYi1PVDEtX3BpdGNoZm9yaw==", Symbol { command: "\\pitchfork", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("⋔") }),
        ("YW1zc3ltYi1PVDEtX21hdGhjYWx7U30=", Symbol { command: "\\mathcal{S}", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.cal(S)") }),
        ("bGF0ZXgyZS1PVDEtX2V4aXN0cw==", Symbol { command: "\\exists", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("exists") }),
        ("YW1zc3ltYi1PVDEtX21hdGhjYWx7SX0=", Symbol { command: "\\mathcal{I}", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.cal(I)") }),
        ("dGV4dGNvbXAtT1QxLV90ZXh0c3Rlcmxpbmc=", Symbol { command: "\\textsterling", package: "textcomp", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: Some("pound") }),
        ("YW1zc3ltYi1PVDEtX2Rvd25oYXJwb29ubGVmdA==", Symbol { command: "\\downharpoonleft", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("harpoon.bl") }),
        ("dXBncmVlay1PVDEtX3VwcGk=", Symbol { command: "\\uppi", package: "upgreek", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX1JzaA==", Symbol { command: "\\Rsh", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("↱") }),
        ("ZXNpbnQtT1QxLV92YXJvaW50Y3RyY2xvY2t3aXNl", Symbol { command: "\\varointctrclockwise", package: "esint", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: None }),
        ("bGF0ZXgyZS1PVDEtX2JpZ29kb3Q=", Symbol { command: "\\bigodot", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("dot.circle.big") }),
        ("YW1zc3ltYi1PVDEtX25taWQ=", Symbol { command: "\\nmid", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("divides.not") }),
        ("d2FzeXN5bS1PVDEtX2JsYWNrc21pbGV5", Symbol { command: "\\blacksmiley", package: "wasysym", font_encoding: "OT1", text_mode: true, math_mode: true, typst_command: None }),
        ("bWFydm9zeW0tT1QxLV9TY29ycGlv", Symbol { command: "\\Scorpio", package: "marvosym", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("bGF0ZXgyZS1PVDEtX2xvbmdsZWZ0cmlnaHRhcnJvdw==", Symbol { command: "\\longleftrightarrow", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("arrow.l.r.long") }),
        ("bGF0ZXgyZS1PVDEtX2xhbWJkYQ==", Symbol { command: "\\lambda", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("lambda") }),
        ("YW1zc3ltYi1PVDEtX21hdGhmcmFre2p9", Symbol { command: "\\mathfrak{j}", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.frak(j)") }),
        ("bGF0ZXgyZS1UMS1fZ3VpbGxlbW90cmlnaHQ=", Symbol { command: "\\guillemotright", package: "latex2e", font_encoding: "T1", text_mode: true, math_mode: false, typst_command: None }),
        ("d2FzeXN5bS1PVDEtX0RPV05hcnJvdw==", Symbol { command: "\\DOWNarrow", package: "wasysym", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("bGF0ZXgyZS1PVDEtX2Rkb3Rz", Symbol { command: "\\ddots", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("dots.down") }),
        ("dGlwYS1PVDEtX3RleHR2ZXJ0bGluZQ==", Symbol { command: "\\textvertline", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("bGF0ZXgyZS1PVDEtX1M=", Symbol { command: "\\S", package: "latex2e", font_encoding: "OT1", text_mode: true, math_mode: true, typst_command: Some("section") }),
        ("c3RtYXJ5cmQtT1QxLV9Mb25nbWFwc2Zyb20=", Symbol { command: "\\Longmapsfrom", package: "stmaryrd", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("arrow.l.double.long.bar") }),
        ("YW1zc3ltYi1PVDEtX21hdGhmcmFre3d9", Symbol { command: "\\mathfrak{w}", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.frak(w)") }),
        ("YW1zc3ltYi1PVDEtX1N1YnNldA==", Symbol { command: "\\Subset", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("subset.double") }),
        ("dGlwYS1PVDEtX3RleHRodHE=", Symbol { command: "\\texthtq", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("dGlwYS1PVDEtX3RleHRidWxsc2V5ZQ==", Symbol { command: "\\textbullseye", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("bGF0ZXgyZS1PVDEtX29kb3Q=", Symbol { command: "\\odot", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("dot.circle") }),
        ("YW1zc3ltYi1PVDEtX2xuZXFx", Symbol { command: "\\lneqq", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("lt.nequiv") }),
        ("YW1zc3ltYi1PVDEtX25wcmVj", Symbol { command: "\\nprec", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("prec.not") }),
        ("bWFydm9zeW0tT1QxLV9MZXR0ZXI=", Symbol { command: "\\Letter", package: "marvosym", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX2JhcndlZGdl", Symbol { command: "\\barwedge", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("⊼") }),
        ("dGV4dGNvbXAtT1QxLV90ZXh0cG0=", Symbol { command: "\\textpm", package: "textcomp", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("bGF0ZXgyZS1PVDEtX30=", Symbol { command: "\\}", package: "latex2e", font_encoding: "OT1", text_mode: true, math_mode: true, typst_command: Some("\\}") }),
        ("YW1zc3ltYi1PVDEtX2ZhbGxpbmdkb3RzZXE=", Symbol { command: "\\fallingdotseq", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("eq.dots.down") }),
        ("dGV4dGNvbXAtT1QxLV90ZXh0aW50ZXJyb2Jhbmdkb3du", Symbol { command: "\\textinterrobangdown", package: "textcomp", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("bGF0ZXgyZS1PVDEtXQ==", Symbol { command: "]", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: None }),
        ("bWF0aHJzZnMtT1QxLV9tYXRoc2Nye0V9", Symbol { command: "\\mathscr{E}", package: "mathrsfs", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.scr(E)") }),
        ("bGF0ZXgyZS1PVDEtX3NoYXJw", Symbol { command: "\\sharp", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("sharp") }),
        ("dGlwYS1PVDEtX3RleHRvcGVuY29ybmVy", Symbol { command: "\\textopencorner", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX21hdGhmcmFre0J9", Symbol { command: "\\mathfrak{B}", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.frak(B)") }),
        ("ZXNpbnQtT1QxLV9maW50", Symbol { command: "\\fint", package: "esint", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("integral.slash") }),
        ("bWF0aHJzZnMtT1QxLV9tYXRoc2Nye0t9", Symbol { command: "\\mathscr{K}", package: "mathrsfs", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.scr(K)") }),
        ("bGF0ZXgyZS1PVDEtX2Rvd25hcnJvdw==", Symbol { command: "\\downarrow", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("arrow.b") }),
        ("dGlwYS1PVDEtX3RleHRyZXZlcHNpbG9u", Symbol { command: "\\textrevepsilon", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("dGV4dGNvbXAtT1QxLV90ZXh0b3BlbmJ1bGxldA==", Symbol { command: "\\textopenbullet", package: "textcomp", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("bGF0ZXgyZS1PVDEtX25hdHVyYWw=", Symbol { command: "\\natural", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("natural") }),
        ("YW1zc3ltYi1PVDEtX2xlZnRyaWdodGFycm93cw==", Symbol { command: "\\leftrightarrows", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("arrows.lr") }),
        ("bGF0ZXgyZS1PVDEtX2xlZnRyaWdodGFycm93", Symbol { command: "\\leftrightarrow", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("<->") }),
        ("YW1zc3ltYi1PVDEtX21hdGhmcmFre1V9", Symbol { command: "\\mathfrak{U}", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.frak(U)") }),
        ("d2FzeXN5bS1PVDEtX3Vucmhk", Symbol { command: "\\unrhd", package: "wasysym", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("gt.tri.eq") }),
        ("ZHNmb250LU9UMS1fbWF0aGRze1F9", Symbol { command: "\\mathds{Q}", package: "dsfont", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.bb(Q)") }),
        ("YW1zc3ltYi1PVDEtX2NpcmNsZWRS", Symbol { command: "\\circledR", package: "amssymb", font_encoding: "OT1", text_mode: true, math_mode: true, typst_command: Some("®") }),
        ("YW1zc3ltYi1PVDEtX3NtYWxsc21pbGU=", Symbol { command: "\\smallsmile", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("⌣") }),
        ("bGF0ZXgyZS1PVDEtX3RleHRiYWNrc2xhc2g=", Symbol { command: "\\textbackslash", package: "latex2e", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: Some("\\\\") }),
        ("bWFydm9zeW0tT1QxLV9NVkF0", Symbol { command: "\\MVAt", package: "marvosym", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("c3RtYXJ5cmQtT1QxLV9sZWZ0cmlnaHRhcnJvd2Vx", Symbol { command: "\\leftrightarroweq", package: "stmaryrd", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: None }),
        ("dGlwYS1PVDEtX3RleHRwaGk=", Symbol { command: "\\textphi", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("bGF0ZXgyZS1PVDEtX2JpZ2N1cA==", Symbol { command: "\\bigcup", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("union.big") }),
        ("YW1zc3ltYi1PVDEtX2d0cmVxbGVzcw==", Symbol { command: "\\gtreqless", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("gt.eq.lt") }),
        ("dGlwYS1PVDEtX3RleHRkY3R6bGln", Symbol { command: "\\textdctzlig", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("bGF0ZXgyZS1PVDEtX1NT", Symbol { command: "\\SS", package: "latex2e", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("dGlwYS1PVDEtX3RleHRnbG9iZmFsbA==", Symbol { command: "\\textglobfall", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX21hdGhmcmFre259", Symbol { command: "\\mathfrak{n}", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.frak(n)") }),
        ("dGlwYS1PVDEtX3RleHRodGc=", Symbol { command: "\\texthtg", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("dGV4dGNvbXAtT1QxLV90ZXh0dXBhcnJvdw==", Symbol { command: "\\textuparrow", package: "textcomp", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("dXBncmVlay1PVDEtX1Vwb21lZ2E=", Symbol { command: "\\Upomega", package: "upgreek", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: None }),
        ("d2FzeXN5bS1PVDEtX29jaXJjbGU=", Symbol { command: "\\ocircle", package: "wasysym", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX2Rhc2hsZWZ0YXJyb3c=", Symbol { command: "\\dashleftarrow", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("arrow.l.dash") }),
        ("dGV4dGNvbXAtT1QxLV90ZXh0ZXVybw==", Symbol { command: "\\texteuro", package: "textcomp", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("dGlwYS1PVDEtX3RleHRzY24=", Symbol { command: "\\textscn", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX2JsYWNrdHJpYW5nbGU=", Symbol { command: "\\blacktriangle", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("triangle.filled.small.t") }),
        ("YW1zc3ltYi1PVDEtX2N1cmx5d2VkZ2U=", Symbol { command: "\\curlywedge", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("and.curly") }),
        ("dGlwYS1PVDEtX3RleHRydGFpbHo=", Symbol { command: "\\textrtailz", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX3ZlZWJhcg==", Symbol { command: "\\veebar", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("⊻") }),
        ("dGlwYS1PVDEtX3RleHR0Y3RjbGln", Symbol { command: "\\texttctclig", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("bGF0ZXgyZS1PVDEtX3dy", Symbol { command: "\\wr", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("wreath") }),
        ("bWFydm9zeW0tT1QxLV9DZWx0Y3Jvc3M=", Symbol { command: "\\Celtcross", package: "marvosym", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX2N1cnZlYXJyb3dyaWdodA==", Symbol { command: "\\curvearrowright", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("arrow.cw.half") }),
        ("bGF0ZXgyZS1PVDEtX2Nvbmc=", Symbol { command: "\\cong", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("tilde.equiv") }),
        ("d2FzeXN5bS1PVDEtX2NoZWNrZWQ=", Symbol { command: "\\checked", package: "wasysym", font_encoding: "OT1", text_mode: true, math_mode: true, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX2RpZ2FtbWE=", Symbol { command: "\\digamma", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("ϝ") }),
        ("YW1zc3ltYi1PVDEtX25zdWNj", Symbol { command: "\\nsucc", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("succ.not") }),
        ("dGV4dGNvbXAtT1QxLV90ZXh0Z3VhcmFuaQ==", Symbol { command: "\\textguarani", package: "textcomp", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("dGV4dGNvbXAtT1QxLV90ZXh0YmlnY2lyY2xl", Symbol { command: "\\textbigcircle", package: "textcomp", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("bGF0ZXgyZS1PVDEtX3N0YXI=", Symbol { command: "\\star", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("star.op") }),
        ("dGlwYS1PVDEtX3RleHRzY3JpcHRh", Symbol { command: "\\textscripta", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX21hdGhiYntRfQ==", Symbol { command: "\\mathbb{Q}", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: None }),
        ("bWF0aGRvdHMtT1QxLV9pZGRvdHM=", Symbol { command: "\\iddots", package: "mathdots", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: None }),
        ("d2FzeXN5bS1PVDEtX3NhZ2l0dGFyaXVz", Symbol { command: "\\sagittarius", package: "wasysym", font_encoding: "OT1", text_mode: true, math_mode: true, typst_command: None }),
        ("dGlwYS1PVDEtX3RleHRsdGFpbG4=", Symbol { command: "\\textltailn", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("dGV4dGNvbXAtT1QxLV90ZXh0cXVvdGVzdHJhaWdodGJhc2U=", Symbol { command: "\\textquotestraightbase", package: "textcomp", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("dGlwYS1PVDEtX3RleHRzY3k=", Symbol { command: "\\textscy", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("bGF0ZXgyZS1PVDEtX2xjZWls", Symbol { command: "\\lceil", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("ceil.l") }),
        ("YW1zc3ltYi1PVDEtX3Nob3J0bWlk", Symbol { command: "\\shortmid", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX0ZpbnY=", Symbol { command: "\\Finv", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("Ⅎ") }),
        ("YW1zc3ltYi1PVDEtX2xlc3NlcWd0cg==", Symbol { command: "\\lesseqgtr", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("lt.eq.gt") }),
        ("YW1zc3ltYi1PVDEtX25sZXE=", Symbol { command: "\\nleq", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("lt.eq.not") }),
        ("bGF0ZXgyZS1UMS1fZ3VpbHNpbmdsbGVmdA==", Symbol { command: "\\guilsinglleft", package: "latex2e", font_encoding: "T1", text_mode: true, math_mode: false, typst_command: None }),
        ("bGF0ZXgyZS1PVDEtX2JpZ3VwbHVz", Symbol { command: "\\biguplus", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("union.plus.big") }),
        ("YW1zc3ltYi1PVDEtX3N1YnNldG5lcXE=", Symbol { command: "\\subsetneqq", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("⫋") }),
        ("dGlwYS1PVDEtX3RleHR0aGV0YQ==", Symbol { command: "\\texttheta", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("bGF0ZXgyZS1PVDEtX2FwcHJveA==", Symbol { command: "\\approx", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("approx") }),
        ("YW1zc3ltYi1PVDEtX21hdGhmcmFre019", Symbol { command: "\\mathfrak{M}", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.frak(M)") }),
        ("d2FzeXN5bS1PVDEtX3NhdHVybg==", Symbol { command: "\\saturn", package: "wasysym", font_encoding: "OT1", text_mode: true, math_mode: true, typst_command: None }),
        ("bGF0ZXgyZS1PVDEtX3RleHRzZWN0aW9u", Symbol { command: "\\textsection", package: "latex2e", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("bWFydm9zeW0tT1QxLV9mYXg=", Symbol { command: "\\fax", package: "marvosym", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("dGlwYS1PVDEtX3RleHRjdHlvZ2g=", Symbol { command: "\\textctyogh", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("dGlwYS1PVDEtX3RleHRvbWVnYQ==", Symbol { command: "\\textomega", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("bGF0ZXgyZS1PVDEtXy0tLQ==", Symbol { command: "\\---", package: "latex2e", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("bGF0ZXgyZS1UMS1fdGV4dHF1b3RlZGJs", Symbol { command: "\\textquotedbl", package: "latex2e", font_encoding: "T1", text_mode: true, math_mode: false, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX2xlcXE=", Symbol { command: "\\leqq", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("lt.equiv") }),
        ("dXBncmVlay1PVDEtX3VwdGF1", Symbol { command: "\\uptau", package: "upgreek", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: None }),
        ("bGF0ZXgyZS1PVDEtX2NvcHJvZA==", Symbol { command: "\\coprod", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("product.co") }),
        ("dXBncmVlay1PVDEtX1VwcGhp", Symbol { command: "\\Upphi", package: "upgreek", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: None }),
        ("dGlwYS1PVDEtX3RleHRyaG9va3JldmVwc2lsb24=", Symbol { command: "\\textrhookrevepsilon", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("dGlwYS1PVDEtX3RleHRseW9naGxpZw==", Symbol { command: "\\textlyoghlig", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("bWFydm9zeW0tT1QxLV9FVVJjcg==", Symbol { command: "\\EURcr", package: "marvosym", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("bGF0ZXgyZS1PVDEtX2xlZnRoYXJwb29udXA=", Symbol { command: "\\leftharpoonup", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("harpoon.lt") }),
        ("YW1zc3ltYi1PVDEtX21hdGhiYntIfQ==", Symbol { command: "\\mathbb{H}", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX21hdGhjYWx7Vn0=", Symbol { command: "\\mathcal{V}", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.cal(V)") }),
        ("bGF0ZXgyZS1PVDEtXy0t", Symbol { command: "\\--", package: "latex2e", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("bWFydm9zeW0tT1QxLV9OZXB0dW5l", Symbol { command: "\\Neptune", package: "marvosym", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("ZHNmb250LU9UMS1fbWF0aGRze1h9", Symbol { command: "\\mathds{X}", package: "dsfont", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.bb(X)") }),
        ("dXBncmVlay1PVDEtX3VwZXRh", Symbol { command: "\\upeta", package: "upgreek", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX2RpdmlkZW9udGltZXM=", Symbol { command: "\\divideontimes", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("times.div") }),
        ("YW1zc3ltYi1PVDEtX3N1Y2NjdXJseWVx", Symbol { command: "\\succcurlyeq", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("succ.curly.eq") }),
        ("YW1zc3ltYi1PVDEtX21hdGhmcmFre1N9", Symbol { command: "\\mathfrak{S}", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.frak(S)") }),
        ("bGF0ZXgyZS1PVDEtX2ptYXRo", Symbol { command: "\\jmath", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("dotless.j") }),
        ("bGF0ZXgyZS1PVDEtX2NsdWJzdWl0", Symbol { command: "\\clubsuit", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("suit.club") }),
        ("ZHNmb250LU9UMS1fbWF0aGRzezF9", Symbol { command: "\\mathds{1}", package: "dsfont", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.bb(1)") }),
        ("YW1zc3ltYi1PVDEtX250cmlhbmdsZWxlZnQ=", Symbol { command: "\\ntriangleleft", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("lt.tri.not") }),
        ("YW1zc3ltYi1PVDEtX2ludGVyY2Fs", Symbol { command: "\\intercal", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("⊺") }),
        ("bGF0ZXgyZS1PVDEtX21hdGhzZWN0aW9u", Symbol { command: "\\mathsection", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("section") }),
        ("bWFydm9zeW0tT1QxLV9Gcm93bnk=", Symbol { command: "\\Frowny", package: "marvosym", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("d2FzeXN5bS1PVDEtX21hcnM=", Symbol { command: "\\mars", package: "wasysym", font_encoding: "OT1", text_mode: true, math_mode: true, typst_command: None }),
        ("bGF0ZXgyZS1PVDEtX3ByZWNlcQ==", Symbol { command: "\\preceq", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("prec.eq") }),
        ("dGV4dGNvbXAtT1QxLV90ZXh0ZXN0aW1hdGVk", Symbol { command: "\\textestimated", package: "textcomp", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("bGF0ZXgyZS1PVDEtX3BhcmFsbGVs", Symbol { command: "\\parallel", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("parallel") }),
        ("YW1zc3ltYi1PVDEtX21hdGhmcmFre1h9", Symbol { command: "\\mathfrak{X}", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.frak(X)") }),
        ("bGF0ZXgyZS1PVDEtX0xvbmdsZWZ0cmlnaHRhcnJvdw==", Symbol { command: "\\Longleftrightarrow", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("arrow.l.r.double.long") }),
        ("d2FzeXN5bS1PVDEtX3dhc3lsb3plbmdl", Symbol { command: "\\wasylozenge", package: "wasysym", font_encoding: "OT1", text_mode: true, math_mode: true, typst_command: None }),
        ("ZXNpbnQtT1QxLV9vaW50Y3RyY2xvY2t3aXNl", Symbol { command: "\\ointctrclockwise", package: "esint", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("integral.cont.ccw") }),
        ("bGF0ZXgyZS1PVDEtX21hdGh1bmRlcnNjb3Jl", Symbol { command: "\\mathunderscore", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: None }),
        ("bGF0ZXgyZS1PVDEtX3Bp", Symbol { command: "\\pi", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("pi") }),
        ("bGF0ZXgyZS1PVDEtX2ludA==", Symbol { command: "\\int", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("integral") }),
        ("bGF0ZXgyZS1PVDEtX2Rhc2h2", Symbol { command: "\\dashv", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("tack.l") }),
        ("bGF0ZXgyZS1PVDEtLw==", Symbol { command: "/", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: None }),
        ("c3RtYXJ5cmQtT1QxLV9ycmNlaWw=", Symbol { command: "\\rrceil", package: "stmaryrd", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX2V0aA==", Symbol { command: "\\eth", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("ð") }),
        ("YW1zc3ltYi1PVDEtX2JhY2tzaW1lcQ==", Symbol { command: "\\backsimeq", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("tilde.eq.rev") }),
        ("dGlwYS1PVDEtX3RleHR0dXJudw==", Symbol { command: "\\textturnw", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX21hdGhmcmFre2Z9", Symbol { command: "\\mathfrak{f}", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.frak(f)") }),
        ("bGF0ZXgyZS1PVDEtX3RleHRkb2xsYXI=", Symbol { command: "\\textdollar", package: "latex2e", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX2xlZnRyaWdodHNxdWlnYXJyb3c=", Symbol { command: "\\leftrightsquigarrow", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("arrow.l.r.wave") }),
        ("bGF0ZXgyZS1PVDEtX2NpcmM=", Symbol { command: "\\circ", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("compose") }),
        ("dGlwYS1PVDEtX3RleHRyZXZl", Symbol { command: "\\textreve", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("bWFydm9zeW0tT1QxLV9Bcmllcw==", Symbol { command: "\\Aries", package: "marvosym", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX0J1bXBlcQ==", Symbol { command: "\\Bumpeq", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("≎") }),
        ("d2FzeXN5bS1PVDEtX3NtaWxleQ==", Symbol { command: "\\smiley", package: "wasysym", font_encoding: "OT1", text_mode: true, math_mode: true, typst_command: None }),
        ("bGF0ZXgyZS1PVDEtX3RleHRhc2NpaWNpcmN1bQ==", Symbol { command: "\\textasciicircum", package: "latex2e", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: Some("\\^") }),
        ("dGlwYS1PVDEtX3RleHRzY2h3YQ==", Symbol { command: "\\textschwa", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX2hzbGFzaA==", Symbol { command: "\\hslash", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("planck.reduce") }),
        ("YW1zc3ltYi1PVDEtX21hdGhmcmFre1R9", Symbol { command: "\\mathfrak{T}", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.frak(T)") }),
        ("dGlwYS1PVDEtX3RleHRkb3VibGVwaXBl", Symbol { command: "\\textdoublepipe", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("bGF0ZXgyZS1PVDEtX2FtYWxn", Symbol { command: "\\amalg", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("product.co") }),
        ("YW1zc3ltYi1PVDEtX3N1Y2NuYXBwcm94", Symbol { command: "\\succnapprox", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("succ.napprox") }),
        ("dXBncmVlay1PVDEtX3VwdmFyZXBzaWxvbg==", Symbol { command: "\\upvarepsilon", package: "upgreek", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: None }),
        ("bGF0ZXgyZS1PVDEtX3dw", Symbol { command: "\\wp", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("℘") }),
        ("bGF0ZXgyZS1PVDEtX2FscGhh", Symbol { command: "\\alpha", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("alpha") }),
        ("YW1zc3ltYi1PVDEtX3ByZWNuc2lt", Symbol { command: "\\precnsim", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("prec.ntilde") }),
        ("dGlwYS1PVDEtX3RleHRiYXJ1", Symbol { command: "\\textbaru", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX0N1cA==", Symbol { command: "\\Cup", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("union.double") }),
        ("dGlwYS1PVDEtX3RleHRkb3VibGViYXJzbGFzaA==", Symbol { command: "\\textdoublebarslash", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("dXBncmVlay1PVDEtX3VwdmFydGhldGE=", Symbol { command: "\\upvartheta", package: "upgreek", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: None }),
        ("bGF0ZXgyZS1PVDEtX3Nxc3Vic2V0ZXE=", Symbol { command: "\\sqsubseteq", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("subset.eq.sq") }),
        ("YW1zc3ltYi1PVDEtX2xlcXNsYW50", Symbol { command: "\\leqslant", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("lt.eq.slant") }),
        ("YW1zc3ltYi1PVDEtX21hdGhiYntFfQ==", Symbol { command: "\\mathbb{E}", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: None }),
        ("c3RtYXJ5cmQtT1QxLV9ubmVhcnJvdw==", Symbol { command: "\\nnearrow", package: "stmaryrd", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: None }),
        ("c3RtYXJ5cmQtT1QxLV9pbnBsdXM=", Symbol { command: "\\inplus", package: "stmaryrd", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: None }),
        ("bGF0ZXgyZS1PVDEtX3NlYXJyb3c=", Symbol { command: "\\searrow", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("arrow.br") }),
        ("dGlwYS1PVDEtX3RleHR2aWJ5eQ==", Symbol { command: "\\textvibyy", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("ZHNmb250LU9UMS1fbWF0aGRze0N9", Symbol { command: "\\mathds{C}", package: "dsfont", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.bb(C)") }),
        ("YW1zc3ltYi1PVDEtX2NpcmNsZWFycm93bGVmdA==", Symbol { command: "\\circlearrowleft", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("arrow.ccw") }),
        ("ZHNmb250LU9UMS1fbWF0aGRze1B9", Symbol { command: "\\mathds{P}", package: "dsfont", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.bb(P)") }),
        ("YW1zc3ltYi1PVDEtX2JsYWNrdHJpYW5nbGVsZWZ0", Symbol { command: "\\blacktriangleleft", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("triangle.filled.l") }),
        ("bGF0ZXgyZS1PVDEtX3hp", Symbol { command: "\\xi", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("xi") }),
        ("dGlwYS1PVDEtX3RleHRsdGlsZGU=", Symbol { command: "\\textltilde", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("bWFydm9zeW0tT1QxLV9MaWJyYQ==", Symbol { command: "\\Libra", package: "marvosym", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("bGF0ZXgyZS1PVDEtX0RlbHRh", Symbol { command: "\\Delta", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("Delta") }),
        ("dGlwYS1PVDEtX3RleHRiYXJj", Symbol { command: "\\textbarc", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("ZHNmb250LU9UMS1fbWF0aGRze1N9", Symbol { command: "\\mathds{S}", package: "dsfont", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.bb(S)") }),
        ("dGlwYS1PVDEtX3RleHRjdGo=", Symbol { command: "\\textctj", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("ZXNpbnQtT1QxLV9zcWlpbnQ=", Symbol { command: "\\sqiint", package: "esint", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: None }),
        ("dXBncmVlay1PVDEtX3VwbGFtYmRh", Symbol { command: "\\uplambda", package: "upgreek", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX2xlZnRyaWdodGhhcnBvb25z", Symbol { command: "\\leftrightharpoons", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("harpoons.ltrb") }),
        ("bWFydm9zeW0tT1QxLV9NYXJz", Symbol { command: "\\Mars", package: "marvosym", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX211bHRpbWFw", Symbol { command: "\\multimap", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("multimap") }),
        ("bGF0ZXgyZS1PVDEtX2RkYWdnZXI=", Symbol { command: "\\ddagger", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("dagger.double") }),
        ("dGlwYS1PVDEtX3RleHRsYW1iZGE=", Symbol { command: "\\textlambda", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("bGF0ZXgyZS1PVDEtX3RleHRkYWdnZXJkYmw=", Symbol { command: "\\textdaggerdbl", package: "latex2e", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: Some("dagger.double") }),
        ("bGF0ZXgyZS1PVDEtX25vdGlu", Symbol { command: "\\notin", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("in.not") }),
        ("bWFydm9zeW0tT1QxLV9Nb29u", Symbol { command: "\\Moon", package: "marvosym", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("bWF0aHJzZnMtT1QxLV9tYXRoc2Nye1B9", Symbol { command: "\\mathscr{P}", package: "mathrsfs", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.scr(P)") }),
        ("YW1zc3ltYi1PVDEtX21hdGhmcmFre219", Symbol { command: "\\mathfrak{m}", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.frak(m)") }),
        ("dGlwYS1PVDEtX3RleHRob29rdG9w", Symbol { command: "\\texthooktop", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX3NtYWxsZnJvd24=", Symbol { command: "\\smallfrown", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: None }),
        ("d2FzeXN5bS1PVDEtX3VubGhk", Symbol { command: "\\unlhd", package: "wasysym", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("lt.tri.eq") }),
        ("YW1zc3ltYi1PVDEtX2Rvd25kb3duYXJyb3dz", Symbol { command: "\\downdownarrows", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("arrows.bb") }),
        ("Z2Vuc3ltYi1PVDEtX2NlbHNpdXM=", Symbol { command: "\\celsius", package: "gensymb", font_encoding: "OT1", text_mode: true, math_mode: true, typst_command: None }),
        ("d2FzeXN5bS1PVDEtX2Jyb2tlbnZlcnQ=", Symbol { command: "\\brokenvert", package: "wasysym", font_encoding: "OT1", text_mode: true, math_mode: true, typst_command: None }),
        ("bWF0aHJzZnMtT1QxLV9tYXRoc2Nye0l9", Symbol { command: "\\mathscr{I}", package: "mathrsfs", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.scr(I)") }),
        ("YW1zc3ltYi1PVDEtX21hdGhmcmFre1l9", Symbol { command: "\\mathfrak{Y}", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.frak(Y)") }),
        ("dGV4dGNvbXAtT1QxLV90ZXh0ZGFnZ2Vy", Symbol { command: "\\textdagger", package: "textcomp", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: Some("dagger") }),
        ("bGF0ZXgyZS1PVDEtX3N1Y2NlcQ==", Symbol { command: "\\succeq", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("succ.eq") }),
        ("YW1zc3ltYi1PVDEtX1N1cHNldA==", Symbol { command: "\\Supset", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("supset.double") }),
        ("YW1zc3ltYi1PVDEtX2JsYWNrdHJpYW5nbGVkb3du", Symbol { command: "\\blacktriangledown", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("triangle.filled.small.b") }),
        ("dGlwYS1PVDEtX3RleHRodGs=", Symbol { command: "\\texthtk", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("d2FzeXN5bS1PVDEtX2dlbWluaQ==", Symbol { command: "\\gemini", package: "wasysym", font_encoding: "OT1", text_mode: true, math_mode: true, typst_command: None }),
        ("bGF0ZXgyZS1PVDEtX2J1bGxldA==", Symbol { command: "\\bullet", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("bullet") }),
        ("bGF0ZXgyZS1PVDEtX0xlZnRyaWdodGFycm93", Symbol { command: "\\Leftrightarrow", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("arrow.l.r.double") }),
        ("YW1zc3ltYi1PVDEtX21hdGhjYWx7Sn0=", Symbol { command: "\\mathcal{J}", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.cal(J)") }),
        ("bGF0ZXhzeW0tT1QxLV9sZWFkc3Rv", Symbol { command: "\\leadsto", package: "latexsym", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("arrow.r.squiggly") }),
        ("dGlwYS1PVDEtX3RleHRpbnZzY3I=", Symbol { command: "\\textinvscr", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("dGV4dGNvbXAtT1QxLV90ZXh0cGVzbw==", Symbol { command: "\\textpeso", package: "textcomp", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("bWFydm9zeW0tT1QxLV9KdXBpdGVy", Symbol { command: "\\Jupiter", package: "marvosym", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("ZHNmb250LU9UMS1fbWF0aGRze0p9", Symbol { command: "\\mathds{J}", package: "dsfont", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.bb(J)") }),
        ("dGlwYS1PVDEtX3RleHRzY2E=", Symbol { command: "\\textsca", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("bGF0ZXgyZS1PVDEtX25vdF9zaW1lcQ==", Symbol { command: "\\not\\simeq", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: None }),
        ("bWF0aHJzZnMtT1QxLV9tYXRoc2Nye0N9", Symbol { command: "\\mathscr{C}", package: "mathrsfs", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.scr(C)") }),
        ("dGlwYS1PVDEtX3RleHRiYXJnbG90c3RvcA==", Symbol { command: "\\textbarglotstop", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX21hdGhiYntUfQ==", Symbol { command: "\\mathbb{T}", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: None }),
        ("bGF0ZXgyZS1PVDEtX0Rvd25hcnJvdw==", Symbol { command: "\\Downarrow", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("arrow.b.double") }),
        ("bGF0ZXgyZS1PVDEtX3RyaWFuZ2xl", Symbol { command: "\\triangle", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("triangle.stroked.t") }),
        ("d2FzeXN5bS1PVDEtX2xoZA==", Symbol { command: "\\lhd", package: "wasysym", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("triangle.stroked.l") }),
        ("dGlwYS1PVDEtX3RleHRjZWx0cGFs", Symbol { command: "\\textceltpal", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("YW1zbWF0aC1PVDEtX2lpaWludA==", Symbol { command: "\\iiiint", package: "amsmath", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("integral.quad") }),
        ("YW1zc3ltYi1PVDEtX0NhcA==", Symbol { command: "\\Cap", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("sect.double") }),
        ("YW1zc3ltYi1PVDEtX21hdGhmcmFre0h9", Symbol { command: "\\mathfrak{H}", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.frak(H)") }),
        ("d2FzeXN5bS1PVDEtX2xpYnJh", Symbol { command: "\\libra", package: "wasysym", font_encoding: "OT1", text_mode: true, math_mode: true, typst_command: None }),
        ("bGF0ZXgyZS1PVDEtX2JpZ3RyaWFuZ2xldXA=", Symbol { command: "\\bigtriangleup", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("triangle.stroked.t") }),
        ("bGF0ZXgyZS1PVDEtX3BlcnA=", Symbol { command: "\\perp", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("perp") }),
        ("d2FzeXN5bS1PVDEtX21lcmN1cnk=", Symbol { command: "\\mercury", package: "wasysym", font_encoding: "OT1", text_mode: true, math_mode: true, typst_command: None }),
        ("bGF0ZXgyZS1PVDEtIWA=", Symbol { command: "!`", package: "latex2e", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX21hdGhmcmFre2d9", Symbol { command: "\\mathfrak{g}", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.frak(g)") }),
        ("YW1zc3ltYi1PVDEtX21obw==", Symbol { command: "\\mho", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("Omega.inv") }),
        ("YW1zc3ltYi1PVDEtX2NvbXBsZW1lbnQ=", Symbol { command: "\\complement", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("complement") }),
        ("YW1zc3ltYi1PVDEtX3Nxc3Vwc2V0", Symbol { command: "\\sqsupset", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("supset.sq") }),
        ("dXBncmVlay1PVDEtX3VwbXU=", Symbol { command: "\\upmu", package: "upgreek", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: None }),
        ("YW1zbWF0aC1PVDEtX2RvdHNp", Symbol { command: "\\dotsi", package: "amsmath", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("dots.h.c") }),
        ("bGF0ZXgyZS1PVDEtX3N1cmQ=", Symbol { command: "\\surd", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("\\√") }),
        ("dGlwYS1PVDEtX3RleHRodHQ=", Symbol { command: "\\texthtt", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("bGF0ZXgyZS1UMS1fdGg=", Symbol { command: "\\th", package: "latex2e", font_encoding: "T1", text_mode: true, math_mode: false, typst_command: Some("th") }),
        ("YW1zc3ltYi1PVDEtX21hdGhjYWx7WH0=", Symbol { command: "\\mathcal{X}", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.cal(X)") }),
        ("dGlwYS1PVDEtX3RleHRjdGVzaA==", Symbol { command: "\\textctesh", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX3Zhcm5vdGhpbmc=", Symbol { command: "\\varnothing", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("nothing") }),
        ("bGF0ZXgyZS1PVDEtX3ZhcmVwc2lsb24=", Symbol { command: "\\varepsilon", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("epsilon") }),
        ("bGF0ZXgyZS1PVDEtX2RvdHM=", Symbol { command: "\\dots", package: "latex2e", font_encoding: "OT1", text_mode: true, math_mode: true, typst_command: Some("dots.h") }),
        ("d2FzeXN5bS1PVDEtX2NhcHJpY29ybnVz", Symbol { command: "\\capricornus", package: "wasysym", font_encoding: "OT1", text_mode: true, math_mode: true, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX3N1YnNldG5lcQ==", Symbol { command: "\\subsetneq", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("subset.neq") }),
        ("bWFydm9zeW0tT1QxLV9CYXQ=", Symbol { command: "\\Bat", package: "marvosym", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX2duZXE=", Symbol { command: "\\gneq", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("gt.neq") }),
        ("d2FzeXN5bS1PVDEtX0xIRA==", Symbol { command: "\\LHD", package: "wasysym", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: None }),
        ("bGF0ZXgyZS1PVDEtXy0tLS0=", Symbol { command: "\\----", package: "latex2e", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX25zdXBzZXRlcQ==", Symbol { command: "\\nsupseteq", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("supset.eq.not") }),
        ("YW1zc3ltYi1PVDEtX21hdGhmcmFre3R9", Symbol { command: "\\mathfrak{t}", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.frak(t)") }),
        ("bGF0ZXgyZS1PVDEtX2w=", Symbol { command: "\\l", package: "latex2e", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("dGlwYS1PVDEtX3RleHRjdHo=", Symbol { command: "\\textctz", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("Y21sbC1PVDEtX3BhcnI=", Symbol { command: "\\parr", package: "cmll", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: None }),
        ("dGV4dGNvbXAtT1QxLV90ZXh0bHF1aWxs", Symbol { command: "\\textlquill", package: "textcomp", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("dGV4dGNvbXAtT1QxLV90ZXh0YnVsbGV0", Symbol { command: "\\textbullet", package: "textcomp", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("bGF0ZXgyZS1PVDEtX0xlZnRhcnJvdw==", Symbol { command: "\\Leftarrow", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("arrow.l.double") }),
        ("YW1zc3ltYi1PVDEtX2NpcmNlcQ==", Symbol { command: "\\circeq", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("≗") }),
        ("bGF0ZXgyZS1PVDEtX2JpZ2NhcA==", Symbol { command: "\\bigcap", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("sect.big") }),
        ("bGF0ZXgyZS1PVDEtX3BoaQ==", Symbol { command: "\\phi", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("phi.alt") }),
        ("d2FzeXN5bS1PVDEtX2Z1bGxtb29u", Symbol { command: "\\fullmoon", package: "wasysym", font_encoding: "OT1", text_mode: true, math_mode: true, typst_command: None }),
        ("ZXNpbnQtT1QxLV9sYW5kZG93bmludA==", Symbol { command: "\\landdownint", package: "esint", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: None }),
        ("YW1zbWF0aC1PVDEtX2RvdHNt", Symbol { command: "\\dotsm", package: "amsmath", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("dots.h.c") }),
        ("dGlwYS1PVDEtX3RleHRzb2Z0c2lnbg==", Symbol { command: "\\textsoftsign", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("dXBncmVlay1PVDEtX3Vwa2FwcGE=", Symbol { command: "\\upkappa", package: "upgreek", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX2Vxc2xhbnRsZXNz", Symbol { command: "\\eqslantless", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("⪕") }),
        ("bGF0ZXgyZS1PVDEtX09F", Symbol { command: "\\OE", package: "latex2e", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: Some("Œ") }),
        ("YW1zc3ltYi1PVDEtX3RoaWNrYXBwcm94", Symbol { command: "\\thickapprox", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("thickapprox") }),
        ("bGF0ZXgyZS1PVDEtX3ZhcnBp", Symbol { command: "\\varpi", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("pi.alt") }),
        ("dGlwYS1PVDEtX3RleHRyYW1zaG9ybnM=", Symbol { command: "\\textramshorns", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("ZXNpbnQtT1QxLV9zcWludA==", Symbol { command: "\\sqint", package: "esint", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("integral.square") }),
        ("YW1zc3ltYi1PVDEtX2duYXBwcm94", Symbol { command: "\\gnapprox", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("gt.napprox") }),
        ("dGV4dGNvbXAtT1QxLV90ZXh0YmFodA==", Symbol { command: "\\textbaht", package: "textcomp", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX21hdGhiYntBfQ==", Symbol { command: "\\mathbb{A}", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX3RyaWFuZ2xlcQ==", Symbol { command: "\\triangleq", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("eq.delta") }),
        ("bGF0ZXgyZS1PVDEtX3RleHRlbGxpcHNpcw==", Symbol { command: "\\textellipsis", package: "latex2e", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: Some("...") }),
        ("bGF0ZXgyZS1PVDEtX2Zyb3du", Symbol { command: "\\frown", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("frown") }),
        ("ZHNmb250LU9UMS1fbWF0aGRze0V9", Symbol { command: "\\mathds{E}", package: "dsfont", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.bb(E)") }),
        ("dGV4dGNvbXAtT1QxLV90ZXh0bXVzaWNhbG5vdGU=", Symbol { command: "\\textmusicalnote", package: "textcomp", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("ZHNmb250LU9UMS1fbWF0aGRze059", Symbol { command: "\\mathds{N}", package: "dsfont", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.bb(N)") }),
        ("dGlwYS1PVDEtX3RleHRoYWxmbGVuZ3Ro", Symbol { command: "\\texthalflength", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("ZXNpbnQtT1QxLV92YXJvaW50Y2xvY2t3aXNl", Symbol { command: "\\varointclockwise", package: "esint", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("integral.cont.cw") }),
        ("YW1zc3ltYi1PVDEtX21hdGhmcmFre299", Symbol { command: "\\mathfrak{o}", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.frak(o)") }),
        ("c3RtYXJ5cmQtT1QxLV9zaG9ydHJpZ2h0YXJyb3c=", Symbol { command: "\\shortrightarrow", package: "stmaryrd", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: None }),
        ("d2FzeXN5bS1PVDEtX1JIRA==", Symbol { command: "\\RHD", package: "wasysym", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: None }),
        ("dGlwYS1PVDEtX3RleHRodHJ0YWlsZA==", Symbol { command: "\\texthtrtaild", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX21hdGhmcmFre0Z9", Symbol { command: "\\mathfrak{F}", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.frak(F)") }),
        ("YW1zc3ltYi1PVDEtX2xvb3BhcnJvd3JpZ2h0", Symbol { command: "\\looparrowright", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("arrow.r.loop") }),
        ("bWFydm9zeW0tT1QxLV9FVVI=", Symbol { command: "\\EUR", package: "marvosym", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("bWFydm9zeW0tT1QxLV9ZaW55YW5n", Symbol { command: "\\Yinyang", package: "marvosym", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX21hdGhmcmFre3p9", Symbol { command: "\\mathfrak{z}", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.frak(z)") }),
        ("YW1zc3ltYi1PVDEtX25yaWdodGFycm93", Symbol { command: "\\nrightarrow", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("arrow.r.not") }),
        ("dGV4dGNvbXAtT1QxLV90ZXh0cnF1aWxs", Symbol { command: "\\textrquill", package: "textcomp", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("dGlwYS1PVDEtX3RleHRydGFpbHM=", Symbol { command: "\\textrtails", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("bGF0ZXgyZS1PVDEtX1BzaQ==", Symbol { command: "\\Psi", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("Psi") }),
        ("bGF0ZXgyZS1PVDEtX3NpbQ==", Symbol { command: "\\sim", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("tilde.op") }),
        ("YW1zc3ltYi1PVDEtX25nZXFx", Symbol { command: "\\ngeqq", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX2d2ZXJ0bmVxcQ==", Symbol { command: "\\gvertneqq", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: None }),
        ("bGF0ZXgyZS1PVDEtX3dlZGdl", Symbol { command: "\\wedge", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("and") }),
        ("dGlwYS1PVDEtX3RleHRjdHRjdGNsaWc=", Symbol { command: "\\textcttctclig", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("bGF0ZXgyZS1UMS1fZGg=", Symbol { command: "\\dh", package: "latex2e", font_encoding: "T1", text_mode: true, math_mode: false, typst_command: None }),
        ("dXBncmVlay1PVDEtX3VwZGVsdGE=", Symbol { command: "\\updelta", package: "upgreek", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: None }),
        ("bGF0ZXgyZS1PVDEtX2lu", Symbol { command: "\\in", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("in") }),
        ("bGF0ZXgyZS1PVDEtX2JpZ3NxY3Vw", Symbol { command: "\\bigsqcup", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("union.sq.big") }),
        ("bWFydm9zeW0tT1QxLV9Nb2JpbGVmb25l", Symbol { command: "\\Mobilefone", package: "marvosym", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("dGV4dGNvbXAtT1QxLV90ZXh0ZnJhY3Rpb25zb2xpZHVz", Symbol { command: "\\textfractionsolidus", package: "textcomp", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX2JsYWNrbG96ZW5nZQ==", Symbol { command: "\\blacklozenge", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("lozenge.filled") }),
        ("bWF0aHJzZnMtT1QxLV9tYXRoc2Nye0d9", Symbol { command: "\\mathscr{G}", package: "mathrsfs", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.scr(G)") }),
        ("dGlwYS1PVDEtX3RleHRodGg=", Symbol { command: "\\texthth", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX2xlc3Nkb3Q=", Symbol { command: "\\lessdot", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("lt.dot") }),
        ("bWFydm9zeW0tT1QxLV9FbWFpbGN0", Symbol { command: "\\Emailct", package: "marvosym", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("dGlwYS1PVDEtX3RleHRjdHQ=", Symbol { command: "\\textctt", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("ZHNmb250LU9UMS1fbWF0aGRze099", Symbol { command: "\\mathds{O}", package: "dsfont", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.bb(O)") }),
        ("YW1zc3ltYi1PVDEtX3JpZ2h0YXJyb3d0YWls", Symbol { command: "\\rightarrowtail", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("arrow.r.tail") }),
        ("bGF0ZXgyZS1PVDEtX21hdGhwYXJhZ3JhcGg=", Symbol { command: "\\mathparagraph", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("pilcrow") }),
        ("dGlwYS1PVDEtX3RleHR0dXJuY2VsaWc=", Symbol { command: "\\textturncelig", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX25MZWZ0cmlnaHRhcnJvdw==", Symbol { command: "\\nLeftrightarrow", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("arrow.l.r.double.not") }),
        ("dGlwYS1PVDEtX3RleHRydGFpbGw=", Symbol { command: "\\textrtaill", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX2FwcHJveGVx", Symbol { command: "\\approxeq", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("approx.eq") }),
        ("bWFydm9zeW0tT1QxLV9NVlJpZ2h0YXJyb3c=", Symbol { command: "\\MVRightarrow", package: "marvosym", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("dGlwYS1PVDEtX3RleHR0dXJudA==", Symbol { command: "\\textturnt", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("c3RtYXJ5cmQtT1QxLV9yYmFn", Symbol { command: "\\rbag", package: "stmaryrd", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("bag.r") }),
        ("d2FzeXN5bS1PVDEtX3Bpc2Nlcw==", Symbol { command: "\\pisces", package: "wasysym", font_encoding: "OT1", text_mode: true, math_mode: true, typst_command: None }),
        ("c3RtYXJ5cmQtT1QxLV9tYXBzZnJvbQ==", Symbol { command: "\\mapsfrom", package: "stmaryrd", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("arrow.l.bar") }),
        ("bGF0ZXgyZS1PVDEtX29tZWdh", Symbol { command: "\\omega", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("omega") }),
        ("YW1zc3ltYi1PVDEtX2xvemVuZ2U=", Symbol { command: "\\lozenge", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("lozenge.stroked") }),
        ("YW1zc3ltYi1PVDEtX21hdGhiYntGfQ==", Symbol { command: "\\mathbb{F}", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: None }),
        ("bGF0ZXgyZS1PVDEtX0w=", Symbol { command: "\\L", package: "latex2e", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("dGlwYS1PVDEtX3RleHRsZW5ndGhtYXJr", Symbol { command: "\\textlengthmark", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("bGF0ZXgyZS1PVDEtX25hYmxh", Symbol { command: "\\nabla", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("nabla") }),
        ("dGV4dGNvbXAtT1QxLV90ZXh0cmVmZXJlbmNlbWFyaw==", Symbol { command: "\\textreferencemark", package: "textcomp", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX25jb25n", Symbol { command: "\\ncong", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("tilde.equiv.not") }),
        ("bGF0ZXgyZS1PVDEtWw==", Symbol { command: "[", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: None }),
        ("dGlwYS1PVDEtX3RleHRydGFpbHQ=", Symbol { command: "\\textrtailt", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX2NlbnRlcmRvdA==", Symbol { command: "\\centerdot", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("dot.op") }),
        ("YW1zc3ltYi1PVDEtX21hdGhjYWx7UH0=", Symbol { command: "\\mathcal{P}", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.cal(P)") }),
        ("YW1zc3ltYi1PVDEtX2RvdGVxZG90", Symbol { command: "\\doteqdot", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("≑") }),
        ("bGF0ZXgyZS1PVDEtX29wbHVz", Symbol { command: "\\oplus", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("xor") }),
        ("bGF0ZXgyZS1UMS1fVEg=", Symbol { command: "\\TH", package: "latex2e", font_encoding: "T1", text_mode: true, math_mode: false, typst_command: None }),
        ("c3RtYXJ5cmQtT1QxLV9sbGZsb29y", Symbol { command: "\\llfloor", package: "stmaryrd", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX21hdGhjYWx7TH0=", Symbol { command: "\\mathcal{L}", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.cal(L)") }),
        ("bGF0ZXgyZS1PVDEtX3NwYWRlc3VpdA==", Symbol { command: "\\spadesuit", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("suit.spade") }),
        ("YW1zc3ltYi1PVDEtX21hdGhmcmFre2x9", Symbol { command: "\\mathfrak{l}", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.frak(l)") }),
        ("dGlwYS1PVDEtX3RleHRjdGM=", Symbol { command: "\\textctc", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("dGV4dGNvbXAtT1QxLV90ZXh0c2VydmljZW1hcms=", Symbol { command: "\\textservicemark", package: "textcomp", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("dGV4dGNvbXAtT1QxLV90ZXh0aW50ZXJyb2Jhbmc=", Symbol { command: "\\textinterrobang", package: "textcomp", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("bGF0ZXgyZS1PVDEtX3RhdQ==", Symbol { command: "\\tau", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("tau") }),
        ("YW1zc3ltYi1PVDEtX2x2ZXJ0bmVxcQ==", Symbol { command: "\\lvertneqq", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: None }),
        ("ZXNpbnQtT1QxLV9kb3RzaW50", Symbol { command: "\\dotsint", package: "esint", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX25wYXJhbGxlbA==", Symbol { command: "\\nparallel", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("parallel.not") }),
        ("bGF0ZXgyZS1PVDEtX2Nkb3Rw", Symbol { command: "\\cdotp", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("dot.c") }),
        ("dXBncmVlay1PVDEtX1VwZ2FtbWE=", Symbol { command: "\\Upgamma", package: "upgreek", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX2xlc3NlcXFndHI=", Symbol { command: "\\lesseqqgtr", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("⪋") }),
        ("ZHNmb250LU9UMS1fbWF0aGRze2h9", Symbol { command: "\\mathds{h}", package: "dsfont", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.bb(h)") }),
        ("bGF0ZXgyZS1PVDEtX3Byb2Q=", Symbol { command: "\\prod", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("product") }),
        ("dGlwYS1PVDEtX3RleHRjcmI=", Symbol { command: "\\textcrb", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX2dnZw==", Symbol { command: "\\ggg", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("gt.triple") }),
        ("YW1zc3ltYi1PVDEtX25sZWZ0cmlnaHRhcnJvdw==", Symbol { command: "\\nleftrightarrow", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("arrow.l.r.not") }),
        ("YW1zc3ltYi1PVDEtX21hdGhmcmFre3F9", Symbol { command: "\\mathfrak{q}", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.frak(q)") }),
        ("YW1zc3ltYi1PVDEtX2N1cmx5dmVl", Symbol { command: "\\curlyvee", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("or.curly") }),
        ("dGlwYS1PVDEtX3RleHRiYWJ5Z2FtbWE=", Symbol { command: "\\textbabygamma", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("dGV4dGNvbXAtT1QxLV90ZXh0Y29weWxlZnQ=", Symbol { command: "\\textcopyleft", package: "textcomp", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX21hdGhmcmFre1J9", Symbol { command: "\\mathfrak{R}", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.frak(R)") }),
        ("YW1zc3ltYi1PVDEtX21hdGhjYWx7Tn0=", Symbol { command: "\\mathcal{N}", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.cal(N)") }),
        ("YW1zc3ltYi1PVDEtX2xlZnRhcnJvd3RhaWw=", Symbol { command: "\\leftarrowtail", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("arrow.l.tail") }),
        ("bWFydm9zeW0tT1QxLV9DYXByaWNvcm4=", Symbol { command: "\\Capricorn", package: "marvosym", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("dGlwYS1PVDEtX3RleHRkb3duc3RlcA==", Symbol { command: "\\textdownstep", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX3Jpc2luZ2RvdHNlcQ==", Symbol { command: "\\risingdotseq", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("eq.dots.up") }),
        ("YW1zc3ltYi1PVDEtX3N1YnNldGVxcQ==", Symbol { command: "\\subseteqq", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("⫅") }),
        ("ZHNmb250LU9UMS1fbWF0aGRze0x9", Symbol { command: "\\mathds{L}", package: "dsfont", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.bb(L)") }),
        ("bGF0ZXgyZS1PVDEtX3N1Y2M=", Symbol { command: "\\succ", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("succ") }),
        ("bGF0ZXgyZS1PVDEtX3RleHRyZWdpc3RlcmVk", Symbol { command: "\\textregistered", package: "latex2e", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: Some("®") }),
        ("bGF0ZXgyZS1PVDEtX3ZhcnBoaQ==", Symbol { command: "\\varphi", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("phi") }),
        ("bGF0ZXgyZS1PVDEtX3Vwc2lsb24=", Symbol { command: "\\upsilon", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("upsilon") }),
        ("YW1zc3ltYi1PVDEtX21hdGhjYWx7WX0=", Symbol { command: "\\mathcal{Y}", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.cal(Y)") }),
        ("YW1zc3ltYi1PVDEtX2N1cnZlYXJyb3dsZWZ0", Symbol { command: "\\curvearrowleft", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("arrow.ccw.half") }),
        ("ZHNmb250LU9UMS1fbWF0aGRze0t9", Symbol { command: "\\mathds{K}", package: "dsfont", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.bb(K)") }),
        ("dGlwYS1PVDEtX3RleHRvcGVubw==", Symbol { command: "\\textopeno", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX3N1Y2NhcHByb3g=", Symbol { command: "\\succapprox", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("succ.approx") }),
        ("YW1zc3ltYi1PVDEtX21hbHRlc2U=", Symbol { command: "\\maltese", package: "amssymb", font_encoding: "OT1", text_mode: true, math_mode: true, typst_command: Some("maltese") }),
        ("d2FzeXN5bS1PVDEtX2JlbGw=", Symbol { command: "\\bell", package: "wasysym", font_encoding: "OT1", text_mode: true, math_mode: true, typst_command: None }),
        ("bGF0ZXgyZS1PVDEtX2FuZ2xl", Symbol { command: "\\angle", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("angle") }),
        ("bWFydm9zeW0tT1QxLV9QaXNjZXM=", Symbol { command: "\\Pisces", package: "marvosym", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX21hdGhiYntZfQ==", Symbol { command: "\\mathbb{Y}", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX3RyaWFuZ2xlbGVmdGVx", Symbol { command: "\\trianglelefteq", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("lt.tri.eq") }),
        ("dGV4dGNvbXAtT1QxLV90ZXh0Ymxhbms=", Symbol { command: "\\textblank", package: "textcomp", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX2NpcmNsZWFycm93cmlnaHQ=", Symbol { command: "\\circlearrowright", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("arrow.cw") }),
        ("bGF0ZXgyZS1PVDEtX2xlZnRhcnJvdw==", Symbol { command: "\\leftarrow", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("arrow.l") }),
        ("c3RtYXJ5cmQtT1QxLV9sbGNlaWw=", Symbol { command: "\\llceil", package: "stmaryrd", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: None }),
        ("d2FzeXN5bS1PVDEtX3ZlbnVz", Symbol { command: "\\venus", package: "wasysym", font_encoding: "OT1", text_mode: true, math_mode: true, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX25zaW0=", Symbol { command: "\\nsim", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("tilde.not") }),
        ("bWFydm9zeW0tT1QxLV9QaWNrdXA=", Symbol { command: "\\Pickup", package: "marvosym", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("c3RtYXJ5cmQtT1QxLV9zc3dhcnJvdw==", Symbol { command: "\\sswarrow", package: "stmaryrd", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: None }),
        ("dGlwYS1PVDEtX3RleHRlcHNpbG9u", Symbol { command: "\\textepsilon", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("dXBncmVlay1PVDEtX3VwdXBzaWxvbg==", Symbol { command: "\\upupsilon", package: "upgreek", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: None }),
        ("bWF0aHJzZnMtT1QxLV9tYXRoc2Nye1R9", Symbol { command: "\\mathscr{T}", package: "mathrsfs", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.scr(T)") }),
        ("d2FzeXN5bS1PVDEtX2N1cnJlbmN5", Symbol { command: "\\currency", package: "wasysym", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("dGlwYS1PVDEtX3RleHRjbG9zZW9tZWdh", Symbol { command: "\\textcloseomega", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX2xuYXBwcm94", Symbol { command: "\\lnapprox", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("lt.napprox") }),
        ("YW1zbWF0aC1PVDEtX2RvdHNi", Symbol { command: "\\dotsb", package: "amsmath", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("dots.h.c") }),
        ("dGV4dGNvbXAtT1QxLV90ZXh0Y2VudA==", Symbol { command: "\\textcent", package: "textcomp", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("Z2Vuc3ltYi1PVDEtX29obQ==", Symbol { command: "\\ohm", package: "gensymb", font_encoding: "OT1", text_mode: true, math_mode: true, typst_command: None }),
        ("bGF0ZXgyZS1PVDEtX25p", Symbol { command: "\\ni", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("in.rev") }),
        ("dGlwYS1PVDEtX3RleHRiYXJkb3RsZXNzag==", Symbol { command: "\\textbardotlessj", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("dGlwYS1PVDEtX3RleHRjcmxhbWJkYQ==", Symbol { command: "\\textcrlambda", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("dGlwYS1PVDEtX3RleHRjcnR3bw==", Symbol { command: "\\textcrtwo", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX3ZhcnN1YnNldG5lcXE=", Symbol { command: "\\varsubsetneqq", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("⫋") }),
        ("bGF0ZXgyZS1PVDEtX2xmbG9vcg==", Symbol { command: "\\lfloor", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("floor.l") }),
        ("dGlwYS1PVDEtX3RleHR0c2xpZw==", Symbol { command: "\\texttslig", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX2xvb3BhcnJvd2xlZnQ=", Symbol { command: "\\looparrowleft", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("arrow.l.loop") }),
        ("dGlwYS1PVDEtX3RleHRodGM=", Symbol { command: "\\texthtc", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("bGF0ZXgyZS1PVDEtX2JhY2tzbGFzaA==", Symbol { command: "\\backslash", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("backslash") }),
        ("d2FzeXN5bS1PVDEtX3JpZ2h0bW9vbg==", Symbol { command: "\\rightmoon", package: "wasysym", font_encoding: "OT1", text_mode: true, math_mode: true, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX21hdGhmcmFre2l9", Symbol { command: "\\mathfrak{i}", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.frak(i)") }),
        ("YW1zc3ltYi1PVDEtX25sZXNz", Symbol { command: "\\nless", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("lt.not") }),
        ("bGF0ZXgyZS1UMS1fREg=", Symbol { command: "\\DH", package: "latex2e", font_encoding: "T1", text_mode: true, math_mode: false, typst_command: None }),
        ("dGlwYS1PVDEtX3RleHRkb3VibGViYXJwaXBl", Symbol { command: "\\textdoublebarpipe", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("bGF0ZXgyZS1PVDEtX3NtaWxl", Symbol { command: "\\smile", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("smile") }),
        ("c3RtYXJ5cmQtT1QxLV9ubndhcnJvdw==", Symbol { command: "\\nnwarrow", package: "stmaryrd", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX3RyaWFuZ2xlcmlnaHRlcQ==", Symbol { command: "\\trianglerighteq", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("gt.tri.eq") }),
        ("bGF0ZXgyZS1PVDEtX3N3YXJyb3c=", Symbol { command: "\\swarrow", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("arrow.bl") }),
        ("bGF0ZXgyZS1PVDEtX3ZhcnNpZ21h", Symbol { command: "\\varsigma", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("sigma.alt") }),
        ("bGF0ZXgyZS1UMS1fREo=", Symbol { command: "\\DJ", package: "latex2e", font_encoding: "T1", text_mode: true, math_mode: false, typst_command: None }),
        ("dGlwYS1PVDEtX3RleHRjb3JuZXI=", Symbol { command: "\\textcorner", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("c3RtYXJ5cmQtT1QxLV9zaG9ydHVwYXJyb3c=", Symbol { command: "\\shortuparrow", package: "stmaryrd", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: None }),
        ("bGF0ZXgyZS1PVDEtX3NpbWVx", Symbol { command: "\\simeq", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("tilde.eq") }),
        ("Z2Vuc3ltYi1PVDEtX2RlZ3JlZQ==", Symbol { command: "\\degree", package: "gensymb", font_encoding: "OT1", text_mode: true, math_mode: true, typst_command: Some("degree") }),
        ("YW1zc3ltYi1PVDEtX2VxY2lyYw==", Symbol { command: "\\eqcirc", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("≖") }),
        ("YW1zc3ltYi1PVDEtX3ByZWNuYXBwcm94", Symbol { command: "\\precnapprox", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("prec.napprox") }),
        ("YW1zc3ltYi1PVDEtX2xs", Symbol { command: "\\ll", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("lt.double") }),
        ("YW1zbWF0aC1PVDEtX2lpbnQ=", Symbol { command: "\\iint", package: "amsmath", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("integral.double") }),
        ("bGF0ZXgyZS1PVDEtX3VwbHVz", Symbol { command: "\\uplus", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("union.plus") }),
        ("dGlwYS1PVDEtX3RleHRiYXJi", Symbol { command: "\\textbarb", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("dGV4dGNvbXAtT1QxLV90ZXh0bGFuZ2xl", Symbol { command: "\\textlangle", package: "textcomp", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX2d0cmRvdA==", Symbol { command: "\\gtrdot", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("gt.dot") }),
        ("dGV4dGNvbXAtT1QxLV90ZXh0b25laGFsZg==", Symbol { command: "\\textonehalf", package: "textcomp", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("dGlwYS1PVDEtX3RleHR0aG9ybg==", Symbol { command: "\\textthorn", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX2duZXFx", Symbol { command: "\\gneqq", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("gt.nequiv") }),
        ("dXBncmVlay1PVDEtX1VwZGVsdGE=", Symbol { command: "\\Updelta", package: "upgreek", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: None }),
        ("dGlwYS1PVDEtX3RleHR0dXJucnJ0YWls", Symbol { command: "\\textturnrrtail", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("bWFydm9zeW0tT1QxLV9HZW1pbmk=", Symbol { command: "\\Gemini", package: "marvosym", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("bGF0ZXgyZS1PVDEtXyY=", Symbol { command: "\\&", package: "latex2e", font_encoding: "OT1", text_mode: true, math_mode: true, typst_command: Some("amp") }),
        ("ZHNmb250LU9UMS1fbWF0aGRze0h9", Symbol { command: "\\mathds{H}", package: "dsfont", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.bb(H)") }),
        ("YW1zc3ltYi1PVDEtX21hdGhmcmFre2N9", Symbol { command: "\\mathfrak{c}", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.frak(c)") }),
        ("bGF0ZXgyZS1PVDEtXyU=", Symbol { command: "\\%", package: "latex2e", font_encoding: "OT1", text_mode: true, math_mode: true, typst_command: Some("%") }),
        ("YW1zc3ltYi1PVDEtX21hdGhmcmFre0N9", Symbol { command: "\\mathfrak{C}", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.frak(C)") }),
        ("bGF0ZXgyZS1PVDEtX3RleHRlbWRhc2g=", Symbol { command: "\\textemdash", package: "latex2e", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: Some("---") }),
        ("c3RtYXJ5cmQtT1QxLV9NYXBzZnJvbQ==", Symbol { command: "\\Mapsfrom", package: "stmaryrd", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("arrow.l.double.bar") }),
        ("c3RtYXJ5cmQtT1QxLV9MYmFn", Symbol { command: "\\Lbag", package: "stmaryrd", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: None }),
        ("bGF0ZXgyZS1PVDEtX1A=", Symbol { command: "\\P", package: "latex2e", font_encoding: "OT1", text_mode: true, math_mode: true, typst_command: Some("pilcrow") }),
        ("bGF0ZXgyZS1PVDEtXyM=", Symbol { command: "\\#", package: "latex2e", font_encoding: "OT1", text_mode: true, math_mode: true, typst_command: Some("hash") }),
        ("c3RtYXJ5cmQtT1QxLV9uaXBsdXM=", Symbol { command: "\\niplus", package: "stmaryrd", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX3R3b2hlYWRyaWdodGFycm93", Symbol { command: "\\twoheadrightarrow", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("arrow.r.twohead") }),
        ("bGF0ZXgyZS1PVDEtX3BzaQ==", Symbol { command: "\\psi", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("psi") }),
        ("dGV4dGNvbXAtT1QxLV90ZXh0ZG9sbGFy", Symbol { command: "\\textdollar", package: "textcomp", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX1JyaWdodGFycm93", Symbol { command: "\\Rrightarrow", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("arrow.r.triple") }),
        ("dGlwYS1PVDEtX3RleHRwYWxob29r", Symbol { command: "\\textpalhook", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("bGF0ZXgyZS1PVDEtX3RleHRwYXJhZ3JhcGg=", Symbol { command: "\\textparagraph", package: "latex2e", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX2RvdHBsdXM=", Symbol { command: "\\dotplus", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("plus.dot") }),
        ("bGF0ZXgyZS1PVDEtX21hcHN0bw==", Symbol { command: "\\mapsto", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("mapsto") }),
        ("bWFydm9zeW0tT1QxLV9MaWdodG5pbmc=", Symbol { command: "\\Lightning", package: "marvosym", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX21hdGhiYntNfQ==", Symbol { command: "\\mathbb{M}", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: None }),
        ("bGF0ZXgyZS1PVDEtX3w=", Symbol { command: "\\|", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("||") }),
        ("dGlwYS1PVDEtX3RleHR0dXJuYQ==", Symbol { command: "\\textturna", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("bWFydm9zeW0tT1QxLV9TbWlsZXk=", Symbol { command: "\\Smiley", package: "marvosym", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("bGF0ZXgyZS1PVDEtX3RpbWVz", Symbol { command: "\\times", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("times") }),
        ("d2FzeXN5bS1PVDEtX3VyYW51cw==", Symbol { command: "\\uranus", package: "wasysym", font_encoding: "OT1", text_mode: true, math_mode: true, typst_command: None }),
        ("dGlwYS1PVDEtX3RleHRzY3I=", Symbol { command: "\\textscr", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("dGV4dGNvbXAtT1QxLV90ZXh0b25lcXVhcnRlcg==", Symbol { command: "\\textonequarter", package: "textcomp", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("bGF0ZXgyZS1PVDEtX2RhZw==", Symbol { command: "\\dag", package: "latex2e", font_encoding: "OT1", text_mode: true, math_mode: true, typst_command: Some("dagger") }),
        ("YW1zc3ltYi1PVDEtX2Vxc2xhbnRndHI=", Symbol { command: "\\eqslantgtr", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("⪖") }),
        ("YW1zc3ltYi1PVDEtX25sZXFx", Symbol { command: "\\nleqq", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX25nZXE=", Symbol { command: "\\ngeq", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("gt.eq.not") }),
        ("dGV4dGNvbXAtT1QxLV90ZXh0cGlsY3Jvdw==", Symbol { command: "\\textpilcrow", package: "textcomp", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX21hdGhmcmFre0F9", Symbol { command: "\\mathfrak{A}", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.frak(A)") }),
        ("dGlwYS1PVDEtX3RleHRydGhvb2s=", Symbol { command: "\\textrthook", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("dGV4dGNvbXAtT1QxLV90ZXh0dHdlbHZldWRhc2g=", Symbol { command: "\\texttwelveudash", package: "textcomp", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX2dlcXE=", Symbol { command: "\\geqq", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("gt.equiv") }),
        ("d2FzeXN5bS1PVDEtX2xlbw==", Symbol { command: "\\leo", package: "wasysym", font_encoding: "OT1", text_mode: true, math_mode: true, typst_command: None }),
        ("bGF0ZXgyZS1PVDEtX25vdF9hcHByb3g=", Symbol { command: "\\not\\approx", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: None }),
        ("dGlwYS1PVDEtX3RleHRzY29tZWdh", Symbol { command: "\\textscomega", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("dGV4dGNvbXAtT1QxLV90ZXh0cmVnaXN0ZXJlZA==", Symbol { command: "\\textregistered", package: "textcomp", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: Some("®") }),
        ("dGlwYS1PVDEtX3RleHRsaHRsb25naQ==", Symbol { command: "\\textlhtlongi", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("bGF0ZXgyZS1PVDEtX2NhcA==", Symbol { command: "\\cap", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("sect") }),
        ("bGF0ZXgyZS1PVDEtX09tZWdh", Symbol { command: "\\Omega", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("Omega") }),
        ("YW1zc3ltYi1PVDEtX3N1cHNldGVxcQ==", Symbol { command: "\\supseteqq", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("⫆") }),
        ("bGF0ZXgyZS1PVDEtX0dhbW1h", Symbol { command: "\\Gamma", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("Gamma") }),
        ("YW1zc3ltYi1PVDEtX21hdGhjYWx7RX0=", Symbol { command: "\\mathcal{E}", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.cal(E)") }),
        ("YW1zc3ltYi1PVDEtX21hdGhjYWx7V30=", Symbol { command: "\\mathcal{W}", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.cal(W)") }),
        ("YW1zc3ltYi1PVDEtX250cmlhbmdsZXJpZ2h0", Symbol { command: "\\ntriangleright", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("gt.tri.not") }),
        ("bWFydm9zeW0tT1QxLV9TYWdpdHRhcml1cw==", Symbol { command: "\\Sagittarius", package: "marvosym", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX2JveHBsdXM=", Symbol { command: "\\boxplus", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("plus.square") }),
        ("bWFydm9zeW0tT1QxLV9Bbmto", Symbol { command: "\\Ankh", package: "marvosym", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("dGlwYS1PVDEtX3RleHRzY2g=", Symbol { command: "\\textsch", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("dGlwYS1PVDEtX3RleHRiYXJs", Symbol { command: "\\textbarl", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX25lcQ==", Symbol { command: "\\neq", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("!=") }),
        ("bGF0ZXgyZS1PVDEtX3RyaWFuZ2xlbGVmdA==", Symbol { command: "\\triangleleft", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("triangle.stroked.l") }),
        ("dGV4dGNvbXAtT1QxLV90ZXh0dGlsZGVsb3c=", Symbol { command: "\\texttildelow", package: "textcomp", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("ZXNpbnQtT1QxLV9vaWludA==", Symbol { command: "\\oiint", package: "esint", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("integral.surf") }),
        ("YW1zc3ltYi1PVDEtX2dlcXNsYW50", Symbol { command: "\\geqslant", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("gt.eq.slant") }),
        ("d2FzeXN5bS1PVDEtX25ld21vb24=", Symbol { command: "\\newmoon", package: "wasysym", font_encoding: "OT1", text_mode: true, math_mode: true, typst_command: None }),
        ("d2FzeXN5bS1PVDEtX2FxdWFyaXVz", Symbol { command: "\\aquarius", package: "wasysym", font_encoding: "OT1", text_mode: true, math_mode: true, typst_command: None }),
        ("bGF0ZXgyZS1PVDEtX2xlZnRoYXJwb29uZG93bg==", Symbol { command: "\\leftharpoondown", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("harpoon.lb") }),
        ("YW1zc3ltYi1PVDEtX2xsbA==", Symbol { command: "\\lll", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("lt.triple") }),
        ("dGlwYS1PVDEtX3RleHRodGQ=", Symbol { command: "\\texthtd", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("c3RtYXJ5cmQtT1QxLV9sZWZ0cmlnaHRhcnJvd3RyaWFuZ2xl", Symbol { command: "\\leftrightarrowtriangle", package: "stmaryrd", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("arrow.l.r.open") }),
        ("YW1zc3ltYi1PVDEtX2JldHdlZW4=", Symbol { command: "\\between", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("≬") }),
        ("YW1zc3ltYi1PVDEtX21hdGhjYWx7S30=", Symbol { command: "\\mathcal{K}", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.cal(K)") }),
        ("ZHNmb250LU9UMS1fbWF0aGRze1d9", Symbol { command: "\\mathds{W}", package: "dsfont", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.bb(W)") }),
        ("YW1zc3ltYi1PVDEtX3R3b2hlYWRsZWZ0YXJyb3c=", Symbol { command: "\\twoheadleftarrow", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("arrow.l.twohead") }),
        ("YW1zc3ltYi1PVDEtX21hdGhjYWx7VX0=", Symbol { command: "\\mathcal{U}", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.cal(U)") }),
        ("bGF0ZXgyZS1PVDEtX0xhbWJkYQ==", Symbol { command: "\\Lambda", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("Lambda") }),
        ("ZHNmb250LU9UMS1fbWF0aGRze1Z9", Symbol { command: "\\mathds{V}", package: "dsfont", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.bb(V)") }),
        ("bGF0ZXgyZS1PVDEtX2RhZ2dlcg==", Symbol { command: "\\dagger", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("dagger") }),
        ("YW1zc3ltYi1PVDEtX3N1Y2NzaW0=", Symbol { command: "\\succsim", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("succ.tilde") }),
        ("bGF0ZXgyZS1PVDEtX18=", Symbol { command: "\\_", package: "latex2e", font_encoding: "OT1", text_mode: true, math_mode: true, typst_command: Some("\\_") }),
        ("dGlwYS1PVDEtX3RleHRzY2w=", Symbol { command: "\\textscl", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX2Rhc2hyaWdodGFycm93", Symbol { command: "\\dashrightarrow", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("arrow.r.dash") }),
        ("dGlwYS1PVDEtX3RleHRwcmltc3RyZXNz", Symbol { command: "\\textprimstress", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("ZXNpbnQtT1QxLV9paWludA==", Symbol { command: "\\iiint", package: "esint", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("integral.triple") }),
        ("dGlwYS1PVDEtX3RleHRzY2c=", Symbol { command: "\\textscg", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX25SaWdodGFycm93", Symbol { command: "\\nRightarrow", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("arrow.r.double.not") }),
        ("YW1zc3ltYi1PVDEtX3Nob3J0cGFyYWxsZWw=", Symbol { command: "\\shortparallel", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("parallel") }),
        ("bWF0aHJzZnMtT1QxLV9tYXRoc2Nye1Z9", Symbol { command: "\\mathscr{V}", package: "mathrsfs", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.scr(V)") }),
        ("bGF0ZXgyZS1PVDEtX3N1YnNldGVx", Symbol { command: "\\subseteq", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("subset.eq") }),
        ("bGF0ZXgyZS1PVDEtX29taW51cw==", Symbol { command: "\\ominus", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("minus.circle") }),
        ("bGF0ZXgyZS1PVDEtX2xvbmdtYXBzdG8=", Symbol { command: "\\longmapsto", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("mapsto.long") }),
        ("dXBncmVlay1PVDEtX3VwcHNp", Symbol { command: "\\uppsi", package: "upgreek", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX3ZhcnRyaWFuZ2xlbGVmdA==", Symbol { command: "\\vartriangleleft", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("lt.tri") }),
        ("YW1zc3ltYi1PVDEtX2NpcmNsZWRjaXJj", Symbol { command: "\\circledcirc", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("compose.o") }),
        ("bGF0ZXgyZS1UMS1fcXVvdGVzaW5nbGJhc2U=", Symbol { command: "\\quotesinglbase", package: "latex2e", font_encoding: "T1", text_mode: true, math_mode: false, typst_command: None }),
        ("YmJvbGQtT1QxLV9tYXRoYmJ7MX0=", Symbol { command: "\\mathbb{1}", package: "bbold", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: None }),
        ("dGlwYS1PVDEtX3RleHRzZWNzdHJlc3M=", Symbol { command: "\\textsecstress", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("dGlwYS1PVDEtX3RleHRiZWx0bA==", Symbol { command: "\\textbeltl", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("bWF0aHJzZnMtT1QxLV9tYXRoc2Nye099", Symbol { command: "\\mathscr{O}", package: "mathrsfs", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.scr(O)") }),
        ("YW1zc3ltYi1PVDEtX250cmlhbmdsZWxlZnRlcQ==", Symbol { command: "\\ntrianglelefteq", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("lt.tri.eq.not") }),
        ("bWF0aHJzZnMtT1QxLV9tYXRoc2Nye0x9", Symbol { command: "\\mathscr{L}", package: "mathrsfs", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.scr(L)") }),
        ("dXBncmVlay1PVDEtX3VwY2hp", Symbol { command: "\\upchi", package: "upgreek", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: None }),
        ("d2FzeXN5bS1PVDEtX2NlbnQ=", Symbol { command: "\\cent", package: "wasysym", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX0xsZWZ0YXJyb3c=", Symbol { command: "\\Lleftarrow", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("arrow.l.triple") }),
        ("bGF0ZXgyZS1PVDEtX2NoaQ==", Symbol { command: "\\chi", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("chi") }),
        ("YW1zc3ltYi1PVDEtX3NxdWFyZQ==", Symbol { command: "\\square", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("square.stroked") }),
        ("YW1zc3ltYi1PVDEtX21hdGhmcmFre2h9", Symbol { command: "\\mathfrak{h}", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.frak(h)") }),
        ("dGlwYS1PVDEtX3RleHR3eW5u", Symbol { command: "\\textwynn", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("dGlwYS1PVDEtX3RleHR0dXJuc2NyaXB0YQ==", Symbol { command: "\\textturnscripta", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX21hdGhmcmFre1B9", Symbol { command: "\\mathfrak{P}", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.frak(P)") }),
        ("YW1zc3ltYi1PVDEtX3RyaWFuZ2xlZG93bg==", Symbol { command: "\\triangledown", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("triangle.stroked.small.b") }),
        ("YW1zc3ltYi1PVDEtX25zaG9ydHBhcmFsbGVs", Symbol { command: "\\nshortparallel", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: None }),
        ("dGV4dGNvbXAtT1QxLV90ZXh0YmFyZGJs", Symbol { command: "\\textbardbl", package: "textcomp", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: Some("‖") }),
        ("bWF0aHJzZnMtT1QxLV9tYXRoc2Nye1V9", Symbol { command: "\\mathscr{U}", package: "mathrsfs", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.scr(U)") }),
        ("bGF0ZXgyZS1PVDEtX3NxY3Vw", Symbol { command: "\\sqcup", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("union.sq") }),
        ("dGlwYS1PVDEtX3RleHR2aWJ5aQ==", Symbol { command: "\\textvibyi", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("bGF0ZXgyZS1PVDEtX2FzdA==", Symbol { command: "\\ast", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("convolve") }),
        ("dXBncmVlay1PVDEtX3VwemV0YQ==", Symbol { command: "\\upzeta", package: "upgreek", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: None }),
        ("bGF0ZXgyZS1PVDEtX28=", Symbol { command: "\\o", package: "latex2e", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: Some("nothing") }),
        ("dGV4dGNvbXAtT1QxLV90ZXh0Y2VudG9sZHN0eWxl", Symbol { command: "\\textcentoldstyle", package: "textcomp", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("dGV4dGNvbXAtT1QxLV90ZXh0cGVydGhvdXNhbmQ=", Symbol { command: "\\textperthousand", package: "textcomp", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX21hdGhmcmFre059", Symbol { command: "\\mathfrak{N}", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.frak(N)") }),
        ("d2FzeXN5bS1PVDEtX2NhbmNlcg==", Symbol { command: "\\cancer", package: "wasysym", font_encoding: "OT1", text_mode: true, math_mode: true, typst_command: None }),
        ("dGlwYS1PVDEtX3RleHRPbHlvZ2hsaWc=", Symbol { command: "\\textOlyoghlig", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("bGF0ZXgyZS1PVDEtX2FsZXBo", Symbol { command: "\\aleph", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("aleph") }),
        ("bGF0ZXgyZS1PVDEtX2JldGE=", Symbol { command: "\\beta", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("beta") }),
        ("YW1zc3ltYi1PVDEtX1ZkYXNo", Symbol { command: "\\Vdash", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("forces") }),
        ("dGV4dGNvbXAtT1QxLV90ZXh0c3VyZA==", Symbol { command: "\\textsurd", package: "textcomp", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX21hdGhiYntCfQ==", Symbol { command: "\\mathbb{B}", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: None }),
        ("dGlwYS1PVDEtX3RleHR0dXJueQ==", Symbol { command: "\\textturny", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("bWF0aHJzZnMtT1QxLV9tYXRoc2Nye1N9", Symbol { command: "\\mathscr{S}", package: "mathrsfs", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.scr(S)") }),
        ("dGlwYS1PVDEtX3RleHRsaHRsb25neQ==", Symbol { command: "\\textlhtlongy", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("dGV4dGNvbXAtT1QxLV90ZXh0ZG93bmFycm93", Symbol { command: "\\textdownarrow", package: "textcomp", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("bGF0ZXgyZS1UMS1fZGo=", Symbol { command: "\\dj", package: "latex2e", font_encoding: "T1", text_mode: true, math_mode: false, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX21hdGhmcmFre3l9", Symbol { command: "\\mathfrak{y}", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.frak(y)") }),
        ("c3RtYXJ5cmQtT1QxLV9SYmFn", Symbol { command: "\\Rbag", package: "stmaryrd", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: None }),
        ("bGF0ZXgyZS1PVDEtX25lZw==", Symbol { command: "\\neg", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("not") }),
        ("bGF0ZXgyZS1PVDEtX3RleHRleGNsYW1kb3du", Symbol { command: "\\textexclamdown", package: "latex2e", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("bGF0ZXgyZS1PVDEtX3ZhcnJobw==", Symbol { command: "\\varrho", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("rho.alt") }),
        ("dGlwYS1PVDEtX3RleHRiYXJp", Symbol { command: "\\textbari", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("bGF0ZXgyZS1PVDEtX0xvbmdyaWdodGFycm93", Symbol { command: "\\Longrightarrow", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("arrow.r.double.long") }),
        ("bGF0ZXgyZS1UMS1fbmc=", Symbol { command: "\\ng", package: "latex2e", font_encoding: "T1", text_mode: true, math_mode: false, typst_command: None }),
        ("d2FzeXN5bS1PVDEtX3BsdXRv", Symbol { command: "\\pluto", package: "wasysym", font_encoding: "OT1", text_mode: true, math_mode: true, typst_command: None }),
        ("dGlwYS1PVDEtX3RleHRmaXNoaG9va3I=", Symbol { command: "\\textfishhookr", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("bWFydm9zeW0tT1QxLV9GYXhtYWNoaW5l", Symbol { command: "\\Faxmachine", package: "marvosym", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("bGF0ZXgyZS1PVDEtX3Nxc3Vwc2V0ZXE=", Symbol { command: "\\sqsupseteq", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("supset.eq.sq") }),
        ("dGlwYS1PVDEtX3RleHR1cHN0ZXA=", Symbol { command: "\\textupstep", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("bGF0ZXgyZS1PVDEtX3Nz", Symbol { command: "\\ss", package: "latex2e", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: Some("ß") }),
        ("bGF0ZXgyZS1PVDEtX2JpZ3RyaWFuZ2xlZG93bg==", Symbol { command: "\\bigtriangledown", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("triangle.stroked.b") }),
        ("dGlwYS1PVDEtX3RleHRodHNjZw==", Symbol { command: "\\texthtscg", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("bGF0ZXgyZS1PVDEtX2dhbW1h", Symbol { command: "\\gamma", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("gamma") }),
        ("bGF0ZXgyZS1PVDEtfA==", Symbol { command: "|", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: None }),
        ("dXBncmVlay1PVDEtX3VwYWxwaGE=", Symbol { command: "\\upalpha", package: "upgreek", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: None }),
        ("bGF0ZXgyZS1PVDEtX2JpZ3ZlZQ==", Symbol { command: "\\bigvee", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("or.big") }),
        ("bGF0ZXgyZS1PVDEtX3NldG1pbnVz", Symbol { command: "\\setminus", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("without") }),
        ("bGF0ZXgyZS1PVDEtXyQ=", Symbol { command: "\\$", package: "latex2e", font_encoding: "OT1", text_mode: true, math_mode: true, typst_command: Some("dollar") }),
        ("bWF0aHJzZnMtT1QxLV9tYXRoc2Nye1d9", Symbol { command: "\\mathscr{W}", package: "mathrsfs", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.scr(W)") }),
        ("YW1zc3ltYi1PVDEtX2xlc3NndHI=", Symbol { command: "\\lessgtr", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("lt.gt") }),
        ("YW1zc3ltYi1PVDEtX21hdGhjYWx7UX0=", Symbol { command: "\\mathcal{Q}", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.cal(Q)") }),
        ("bGF0ZXgyZS1PVDEtX3RoZXRh", Symbol { command: "\\theta", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("theta") }),
        ("YW1zc3ltYi1PVDEtX3J0aW1lcw==", Symbol { command: "\\rtimes", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("times.r") }),
        ("YW1zc3ltYi1PVDEtX2JsYWNrdHJpYW5nbGVyaWdodA==", Symbol { command: "\\blacktriangleright", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("triangle.filled.r") }),
        ("bGF0ZXgyZS1PVDEtX21hdGhkb2xsYXI=", Symbol { command: "\\mathdollar", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("peso") }),
        ("dGlwYS1PVDEtX3RleHRnYW1tYQ==", Symbol { command: "\\textgamma", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("bGF0ZXgyZS1PVDEtX3RleHRxdWVzdGlvbmRvd24=", Symbol { command: "\\textquestiondown", package: "latex2e", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("dGlwYS1PVDEtX3RleHRiYXJyZXZnbG90c3RvcA==", Symbol { command: "\\textbarrevglotstop", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX2JhY2tlcHNpbG9u", Symbol { command: "\\backepsilon", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("in.rev.small") }),
        ("bWF0aHJzZnMtT1QxLV9tYXRoc2Nye019", Symbol { command: "\\mathscr{M}", package: "mathrsfs", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.scr(M)") }),
        ("dGV4dGNvbXAtT1QxLV90ZXh0cGVydGVudGhvdXNhbmQ=", Symbol { command: "\\textpertenthousand", package: "textcomp", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX21lYXN1cmVkYW5nbGU=", Symbol { command: "\\measuredangle", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("angle.arc") }),
        ("dGlwYS1PVDEtX3RleHRodGJhcmRvdGxlc3Nq", Symbol { command: "\\texthtbardotlessj", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX21hdGhmcmFre2F9", Symbol { command: "\\mathfrak{a}", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.frak(a)") }),
        ("bGF0ZXgyZS1PVDEtX2RkYWc=", Symbol { command: "\\ddag", package: "latex2e", font_encoding: "OT1", text_mode: true, math_mode: true, typst_command: Some("dagger.double") }),
        ("bGF0ZXgyZS1PVDEtX2thcHBh", Symbol { command: "\\kappa", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("kappa") }),
        ("bGF0ZXgyZS1PVDEtX3RleHRxdW90ZXJpZ2h0", Symbol { command: "\\textquoteright", package: "latex2e", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: Some("quote.r.single") }),
        ("bWFydm9zeW0tT1QxLV9NdW5kdXM=", Symbol { command: "\\Mundus", package: "marvosym", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("bGF0ZXgyZS1PVDEtX1RoZXRh", Symbol { command: "\\Theta", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("Theta") }),
        ("bWFydm9zeW0tT1QxLV9BcXVhcml1cw==", Symbol { command: "\\Aquarius", package: "marvosym", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("bWF0aHJzZnMtT1QxLV9tYXRoc2Nye1J9", Symbol { command: "\\mathscr{R}", package: "mathrsfs", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.scr(R)") }),
        ("bGF0ZXgyZS1PVDEtX2Fh", Symbol { command: "\\aa", package: "latex2e", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: Some("circle(A)") }),
        ("bGF0ZXgyZS1PVDEtX21hdGhlbGxpcHNpcw==", Symbol { command: "\\mathellipsis", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("...") }),
        ("d2FzeXN5bS1PVDEtX2RpYW1ldGVy", Symbol { command: "\\diameter", package: "wasysym", font_encoding: "OT1", text_mode: true, math_mode: true, typst_command: Some("diameter") }),
        ("bGF0ZXgyZS1PVDEtX3NxY2Fw", Symbol { command: "\\sqcap", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("sect.sq") }),
        ("bGF0ZXgyZS1PVDEtX3RleHRsZXNz", Symbol { command: "\\textless", package: "latex2e", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: Some("lt") }),
        ("dGV4dGNvbXAtT1QxLV90ZXh0Y2lyY2xlZFA=", Symbol { command: "\\textcircledP", package: "textcomp", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("bGF0ZXgyZS1PVDEtX3BhcnRpYWw=", Symbol { command: "\\partial", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("partial") }),
        ("dXBncmVlay1PVDEtX1Vwc2lnbWE=", Symbol { command: "\\Upsigma", package: "upgreek", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: None }),
        ("bGF0ZXgyZS1PVDEtX2JvdA==", Symbol { command: "\\bot", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("tack.t") }),
        ("dGV4dGNvbXAtT1QxLV90ZXh0dGhyZWVxdWFydGVyc2VtZGFzaA==", Symbol { command: "\\textthreequartersemdash", package: "textcomp", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("dGlwYS1PVDEtX3RleHRjbG9zZWVwc2lsb24=", Symbol { command: "\\textcloseepsilon", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("bWF0aHJzZnMtT1QxLV9tYXRoc2Nye0p9", Symbol { command: "\\mathscr{J}", package: "mathrsfs", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.scr(J)") }),
        ("dGV4dGNvbXAtT1QxLV90ZXh0dGhyZWVxdWFydGVycw==", Symbol { command: "\\textthreequarters", package: "textcomp", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("bGF0ZXgyZS1PVDEtX1Jl", Symbol { command: "\\Re", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("Re") }),
        ("bGF0ZXgyZS1PVDEtX211", Symbol { command: "\\mu", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("mu") }),
        ("dGlwYS1PVDEtX3RleHRyZXZhcG9zdHJvcGhl", Symbol { command: "\\textrevapostrophe", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX3ZhcnN1cHNldG5lcQ==", Symbol { command: "\\varsupsetneq", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("supset.neq") }),
        ("d2FzeXN5bS1PVDEtX2FyaWVz", Symbol { command: "\\aries", package: "wasysym", font_encoding: "OT1", text_mode: true, math_mode: true, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX2dn", Symbol { command: "\\gg", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("gt.double") }),
        ("dGlwYS1PVDEtX3RleHRnbG90c3RvcA==", Symbol { command: "\\textglotstop", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX3VwdXBhcnJvd3M=", Symbol { command: "\\upuparrows", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("arrows.tt") }),
        ("bGF0ZXgyZS1PVDEtX3Bt", Symbol { command: "\\pm", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("plus.minus") }),
        ("YW1zc3ltYi1PVDEtX21hdGhmcmFre0l9", Symbol { command: "\\mathfrak{I}", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.frak(I)") }),
        ("bGF0ZXgyZS1PVDEtX2luZnR5", Symbol { command: "\\infty", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("oo") }),
        ("dGV4dGNvbXAtT1QxLV90ZXh0bGVmdGFycm93", Symbol { command: "\\textleftarrow", package: "textcomp", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("bWF0aHJzZnMtT1QxLV9tYXRoc2Nye1h9", Symbol { command: "\\mathscr{X}", package: "mathrsfs", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.scr(X)") }),
        ("bGF0ZXgyZS1PVDEtX3RleHRwZXJpb2RjZW50ZXJlZA==", Symbol { command: "\\textperiodcentered", package: "latex2e", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX3JpZ2h0bGVmdGhhcnBvb25z", Symbol { command: "\\rightleftharpoons", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("harpoons.rtlb") }),
        ("YW1zc3ltYi1PVDEtX3ZhcnByb3B0bw==", Symbol { command: "\\varpropto", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("prop") }),
        ("dXBncmVlay1PVDEtX3VwZXBzaWxvbg==", Symbol { command: "\\upepsilon", package: "upgreek", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: None }),
        ("dXBncmVlay1PVDEtX3VwbnU=", Symbol { command: "\\upnu", package: "upgreek", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX3ByZWNhcHByb3g=", Symbol { command: "\\precapprox", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("prec.approx") }),
        ("YW1zc3ltYi1PVDEtX21hdGhiYntDfQ==", Symbol { command: "\\mathbb{C}", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: None }),
        ("bGF0ZXgyZS1PVDEtX3JpZ2h0YXJyb3c=", Symbol { command: "\\rightarrow", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("arrow.r") }),
        ("dXBncmVlay1PVDEtX1VweGk=", Symbol { command: "\\Upxi", package: "upgreek", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: None }),
        ("bGF0ZXgyZS1PVDEtX3RleHRkYWdnZXI=", Symbol { command: "\\textdagger", package: "latex2e", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: Some("dagger") }),
        ("dGlwYS1PVDEtX3RleHRzY2I=", Symbol { command: "\\textscb", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX3ZhcnN1YnNldG5lcQ==", Symbol { command: "\\varsubsetneq", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("subset.neq") }),
        ("dGV4dGNvbXAtT1QxLV90ZXh0cGFyYWdyYXBo", Symbol { command: "\\textparagraph", package: "textcomp", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("dGlwYS1PVDEtX3RleHRnbG9icmlzZQ==", Symbol { command: "\\textglobrise", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX21hdGhiYntafQ==", Symbol { command: "\\mathbb{Z}", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: None }),
        ("dGV4dGNvbXAtT1QxLV90ZXh0YnJva2VuYmFy", Symbol { command: "\\textbrokenbar", package: "textcomp", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("dGV4dGNvbXAtT1QxLV90ZXh0b25lc3VwZXJpb3I=", Symbol { command: "\\textonesuperior", package: "textcomp", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX2JpZ3N0YXI=", Symbol { command: "\\bigstar", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("star.filled") }),
        ("bGF0ZXgyZS1PVDEtX3Jobw==", Symbol { command: "\\rho", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("rho") }),
        ("dGV4dGNvbXAtT1QxLV90ZXh0c2VjdGlvbg==", Symbol { command: "\\textsection", package: "textcomp", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX21hdGhjYWx7R30=", Symbol { command: "\\mathcal{G}", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.cal(G)") }),
        ("bGF0ZXgyZS1PVDEtX3N1cHNldA==", Symbol { command: "\\supset", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("supset") }),
        ("bGF0ZXgyZS1PVDEtX3JpZ2h0aGFycG9vbnVw", Symbol { command: "\\rightharpoonup", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("harpoon.rt") }),
        ("dGlwYS1PVDEtX3RleHRjcmludmdsb3RzdG9w", Symbol { command: "\\textcrinvglotstop", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("dGV4dGNvbXAtT1QxLV90ZXh0ZGVncmVl", Symbol { command: "\\textdegree", package: "textcomp", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: Some("degree") }),
        ("bGF0ZXgyZS1PVDEtX2hvb2tsZWZ0YXJyb3c=", Symbol { command: "\\hookleftarrow", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("arrow.l.hook") }),
        ("dXBncmVlay1PVDEtX3VweGk=", Symbol { command: "\\upxi", package: "upgreek", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX21hdGhmcmFre099", Symbol { command: "\\mathfrak{O}", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.frak(O)") }),
        ("bWFydm9zeW0tT1QxLV9TaGlsbGluZw==", Symbol { command: "\\Shilling", package: "marvosym", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("bGF0ZXgyZS1PVDEtX29l", Symbol { command: "\\oe", package: "latex2e", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: Some("œ") }),
        ("YW1zc3ltYi1PVDEtX21hdGhiYntXfQ==", Symbol { command: "\\mathbb{W}", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: None }),
        ("dXBncmVlay1PVDEtX1VwcGk=", Symbol { command: "\\Uppi", package: "upgreek", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: None }),
        ("bGF0ZXgyZS1PVDEtX2NvbG9u", Symbol { command: "\\colon", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("colon") }),
        ("YW1zc3ltYi1PVDEtX2xuZXE=", Symbol { command: "\\lneq", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("lt.neq") }),
        ("bWFydm9zeW0tT1QxLV9IZWFydA==", Symbol { command: "\\Heart", package: "marvosym", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("bWF0aHJzZnMtT1QxLV9tYXRoc2Nye0J9", Symbol { command: "\\mathscr{B}", package: "mathrsfs", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.scr(B)") }),
        ("dGlwYS1PVDEtX3RleHR0dXJubQ==", Symbol { command: "\\textturnm", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("bGF0ZXgyZS1PVDEtX2VsbA==", Symbol { command: "\\ell", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("ell") }),
        ("YW1zc3ltYi1PVDEtX21hdGhjYWx7QX0=", Symbol { command: "\\mathcal{A}", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.cal(A)") }),
        ("YW1zc3ltYi1PVDEtX21hdGhiYntMfQ==", Symbol { command: "\\mathbb{L}", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX21hdGhjYWx7TX0=", Symbol { command: "\\mathcal{M}", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.cal(M)") }),
        ("c3RtYXJ5cmQtT1QxLV9zc2VhcnJvdw==", Symbol { command: "\\ssearrow", package: "stmaryrd", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: None }),
        ("dGlwYS1PVDEtX3RleHR0ZXNobGln", Symbol { command: "\\textteshlig", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("bWFydm9zeW0tT1QxLV9DYW5jZXI=", Symbol { command: "\\Cancer", package: "marvosym", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("bGF0ZXgyZS1PVDEtX3RyaWFuZ2xlcmlnaHQ=", Symbol { command: "\\triangleright", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("triangle.stroked.r") }),
        ("YW1zc3ltYi1PVDEtX21hdGhmcmFre3B9", Symbol { command: "\\mathfrak{p}", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.frak(p)") }),
        ("dGV4dGNvbXAtT1QxLV90ZXh0dGhyZWVzdXBlcmlvcg==", Symbol { command: "\\textthreesuperior", package: "textcomp", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("bWFydm9zeW0tT1QxLV9FVVJ0bQ==", Symbol { command: "\\EURtm", package: "marvosym", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("ZHNmb250LU9UMS1fbWF0aGRze2t9", Symbol { command: "\\mathds{k}", package: "dsfont", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.bb(k)") }),
        ("Y21sbC1PVDEtX3dpdGg=", Symbol { command: "\\with", package: "cmll", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: None }),
        ("d2FzeXN5bS1PVDEtX0xFRlRhcnJvdw==", Symbol { command: "\\LEFTarrow", package: "wasysym", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("bGF0ZXgyZS1PVDEtX3ByZWM=", Symbol { command: "\\prec", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("prec") }),
        ("bGF0ZXgyZS1PVDEtX3NxcnR7fQ==", Symbol { command: "\\sqrt{}", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX21hdGhiYntEfQ==", Symbol { command: "\\mathbb{D}", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX21hdGhmcmFre1p9", Symbol { command: "\\mathfrak{Z}", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.frak(Z)") }),
        ("dGV4dGNvbXAtT1QxLV90ZXh0ZGFnZ2VyZGJs", Symbol { command: "\\textdaggerdbl", package: "textcomp", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: Some("dagger.double") }),
        ("bGF0ZXgyZS1PVDEtX1JpZ2h0YXJyb3c=", Symbol { command: "\\Rightarrow", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("arrow.r.double") }),
        ("dGlwYS1PVDEtX3RleHRjb21tYXRhaWx6", Symbol { command: "\\textcommatailz", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("d2FzeXN5bS1PVDEtX3Zlcm5hbA==", Symbol { command: "\\vernal", package: "wasysym", font_encoding: "OT1", text_mode: true, math_mode: true, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX2RvdWJsZWJhcndlZGdl", Symbol { command: "\\doublebarwedge", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("⩞") }),
        ("bGF0ZXgyZS1PVDEtX3ZhcnRoZXRh", Symbol { command: "\\vartheta", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("theta.alt") }),
        ("bGF0ZXgyZS1PVDEtX3RleHR2aXNpYmxlc3BhY2U=", Symbol { command: "\\textvisiblespace", package: "latex2e", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("dGV4dGNvbXAtT1QxLV90ZXh0dHJhZGVtYXJr", Symbol { command: "\\texttrademark", package: "textcomp", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("d2FzeXN5bS1PVDEtX2Zyb3duaWU=", Symbol { command: "\\frownie", package: "wasysym", font_encoding: "OT1", text_mode: true, math_mode: true, typst_command: None }),
        ("bGF0ZXgyZS1PVDEtX3N1YnNldA==", Symbol { command: "\\subset", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("subset") }),
        ("YW1zc3ltYi1PVDEtX21hdGhiYntVfQ==", Symbol { command: "\\mathbb{U}", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: None }),
        ("ZHNmb250LU9UMS1fbWF0aGRze1J9", Symbol { command: "\\mathds{R}", package: "dsfont", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.bb(R)") }),
        ("bGF0ZXgyZS1PVDEtX2NvcHlyaWdodA==", Symbol { command: "\\copyright", package: "latex2e", font_encoding: "OT1", text_mode: true, math_mode: true, typst_command: Some("copyright") }),
        ("bGF0ZXgyZS1PVDEtX0FB", Symbol { command: "\\AA", package: "latex2e", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: Some("circle(A)") }),
        ("YW1zc3ltYi1PVDEtX2xlZnR0aHJlZXRpbWVz", Symbol { command: "\\leftthreetimes", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("times.three.l") }),
        ("dGlwYS1PVDEtX3RleHR0dXJucg==", Symbol { command: "\\textturnr", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("bWFydm9zeW0tT1QxLV9EZW5hcml1cw==", Symbol { command: "\\Denarius", package: "marvosym", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("bGF0ZXgyZS1PVDEtX2ZvcmFsbA==", Symbol { command: "\\forall", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("forall") }),
        ("bGF0ZXgyZS1PVDEtX2xvbmdyaWdodGFycm93", Symbol { command: "\\longrightarrow", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("arrow.r.long") }),
        ("bWF0aHJzZnMtT1QxLV9tYXRoc2Nye059", Symbol { command: "\\mathscr{N}", package: "mathrsfs", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.scr(N)") }),
        ("dGlwYS1PVDEtX3RleHRjdG4=", Symbol { command: "\\textctn", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("bGF0ZXgyZS1PVDEtX2xkb3Rw", Symbol { command: "\\ldotp", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some(".") }),
        ("bGF0ZXgyZS1PVDEtX2hvb2tyaWdodGFycm93", Symbol { command: "\\hookrightarrow", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("arrow.r.hook") }),
        ("YW1zc3ltYi1PVDEtX3ZEYXNo", Symbol { command: "\\vDash", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("tack.r.double") }),
        ("d2FzeXN5bS1PVDEtX0Jvd3RpZQ==", Symbol { command: "\\Bowtie", package: "wasysym", font_encoding: "OT1", text_mode: true, math_mode: true, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX21hdGhjYWx7Wn0=", Symbol { command: "\\mathcal{Z}", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.cal(Z)") }),
        ("YW1zc3ltYi1PVDEtX21hdGhmcmFre2R9", Symbol { command: "\\mathfrak{d}", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.frak(d)") }),
        ("YW1zc3ltYi1PVDEtX21hdGhiYntSfQ==", Symbol { command: "\\mathbb{R}", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: None }),
        ("bGF0ZXgyZS1PVDEtX3ByaW1l", Symbol { command: "\\prime", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("prime") }),
        ("bGF0ZXgyZS1PVDEtX3RleHRvcmRmZW1pbmluZQ==", Symbol { command: "\\textordfeminine", package: "latex2e", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("dGlwYS1PVDEtX3RleHRjcmQ=", Symbol { command: "\\textcrd", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("dXBncmVlay1PVDEtX1VwdGhldGE=", Symbol { command: "\\Uptheta", package: "upgreek", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: None }),
        ("bGF0ZXgyZS1PVDEtX1hp", Symbol { command: "\\Xi", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("Xi") }),
        ("YW1zc3ltYi1PVDEtX2NoZWNrbWFyaw==", Symbol { command: "\\checkmark", package: "amssymb", font_encoding: "OT1", text_mode: true, math_mode: true, typst_command: Some("checkmark") }),
        ("YW1zc3ltYi1PVDEtX2hiYXI=", Symbol { command: "\\hbar", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("planck.reduce") }),
        ("YW1zc3ltYi1PVDEtX252ZGFzaA==", Symbol { command: "\\nvdash", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("tack.r.not") }),
        ("d2FzeXN5bS1PVDEtX2xpZ2h0bmluZw==", Symbol { command: "\\lightning", package: "wasysym", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("bGF0ZXgyZS1PVDEtX25lYXJyb3c=", Symbol { command: "\\nearrow", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("arrow.tr") }),
        ("bWF0aHJzZnMtT1QxLV9tYXRoc2Nye0h9", Symbol { command: "\\mathscr{H}", package: "mathrsfs", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.scr(H)") }),
        ("dGV4dGNvbXAtT1QxLV90ZXh0eWVu", Symbol { command: "\\textyen", package: "textcomp", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("bGF0ZXgyZS1PVDEtX3RleHRxdW90ZWxlZnQ=", Symbol { command: "\\textquoteleft", package: "latex2e", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: Some("quote.l.single") }),
        ("d2FzeXN5bS1PVDEtX29wcG9zaXRpb24=", Symbol { command: "\\opposition", package: "wasysym", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("d2FzeXN5bS1PVDEtX3Bob25l", Symbol { command: "\\phone", package: "wasysym", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("d2FzeXN5bS1PVDEtX2Rlc2Nub2Rl", Symbol { command: "\\descnode", package: "wasysym", font_encoding: "OT1", text_mode: true, math_mode: true, typst_command: None }),
        ("c3RtYXJ5cmQtT1QxLV9ycnBhcmVudGhlc2lz", Symbol { command: "\\rrparenthesis", package: "stmaryrd", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("paren.r.closed") }),
        ("bWFydm9zeW0tT1QxLV9VcmFudXM=", Symbol { command: "\\Uranus", package: "marvosym", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("dGV4dGNvbXAtT1QxLV90ZXh0cmlnaHRhcnJvdw==", Symbol { command: "\\textrightarrow", package: "textcomp", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("bGF0ZXgyZS1PVDEtX2Jvd3RpZQ==", Symbol { command: "\\bowtie", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("⋈") }),
        ("ZXNpbnQtT1QxLV92YXJvaWludA==", Symbol { command: "\\varoiint", package: "esint", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: None }),
        ("bGF0ZXgyZS1UMS1fcXVvdGVkYmxiYXNl", Symbol { command: "\\quotedblbase", package: "latex2e", font_encoding: "T1", text_mode: true, math_mode: false, typst_command: None }),
        ("dGlwYS1PVDEtX3RleHRjbG9zZXJldmVwc2lsb24=", Symbol { command: "\\textcloserevepsilon", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX3JpZ2h0dGhyZWV0aW1lcw==", Symbol { command: "\\rightthreetimes", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("times.three.r") }),
        ("YW1zc3ltYi1PVDEtX21hdGhmcmFre0p9", Symbol { command: "\\mathfrak{J}", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.frak(J)") }),
        ("c3RtYXJ5cmQtT1QxLV9sYmFn", Symbol { command: "\\lbag", package: "stmaryrd", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("bag.l") }),
        ("YW1zc3ltYi1PVDEtX0xzaA==", Symbol { command: "\\Lsh", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("↰") }),
        ("bWF0aHJzZnMtT1QxLV9tYXRoc2Nye0R9", Symbol { command: "\\mathscr{D}", package: "mathrsfs", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.scr(D)") }),
        ("ZHNmb250LU9UMS1fbWF0aGRze0R9", Symbol { command: "\\mathds{D}", package: "dsfont", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.bb(D)") }),
        ("ZHNmb250LU9UMS1fbWF0aGRze1l9", Symbol { command: "\\mathds{Y}", package: "dsfont", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.bb(Y)") }),
        ("bGF0ZXgyZS1PVDEtX2hlYXJ0c3VpdA==", Symbol { command: "\\heartsuit", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("suit.heart.stroked") }),
        ("bGF0ZXgyZS1PVDEtX3JmbG9vcg==", Symbol { command: "\\rfloor", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("floor.r") }),
        ("dGV4dGNvbXAtT1QxLV90ZXh0bmFpcmE=", Symbol { command: "\\textnaira", package: "textcomp", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("dGlwYS1PVDEtX3RleHR0dXJuaA==", Symbol { command: "\\textturnh", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX21hdGhmcmFre0d9", Symbol { command: "\\mathfrak{G}", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.frak(G)") }),
        ("bGF0ZXgyZS1PVDEtX3RleHRjb3B5cmlnaHQ=", Symbol { command: "\\textcopyright", package: "latex2e", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX2d0cmxlc3M=", Symbol { command: "\\gtrless", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("gt.lt") }),
        ("dGlwYS1PVDEtX3RleHRzY3JpcHR2", Symbol { command: "\\textscriptv", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("c3RtYXJ5cmQtT1QxLV9yaWdodGFycm93dHJpYW5nbGU=", Symbol { command: "\\rightarrowtriangle", package: "stmaryrd", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("arrow.r.open") }),
        ("dGlwYS1PVDEtX3RleHR5b2do", Symbol { command: "\\textyogh", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("bWFydm9zeW0tT1QxLV9FbWFpbA==", Symbol { command: "\\Email", package: "marvosym", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX21hdGhmcmFre1Z9", Symbol { command: "\\mathfrak{V}", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.frak(V)") }),
        ("bGF0ZXgyZS1PVDEtX2V0YQ==", Symbol { command: "\\eta", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("eta") }),
        ("YW1zc3ltYi1PVDEtX21hdGhmcmFre1F9", Symbol { command: "\\mathfrak{Q}", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.frak(Q)") }),
        ("c3RtYXJ5cmQtT1QxLV9ycmJyYWNrZXQ=", Symbol { command: "\\rrbracket", package: "stmaryrd", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("bracket.r.double") }),
        ("d2FzeXN5bS1PVDEtX1JJR0hUYXJyb3c=", Symbol { command: "\\RIGHTarrow", package: "wasysym", font_encoding: "OT1", text_mode: true, math_mode: true, typst_command: None }),
        ("dGV4dGNvbXAtT1QxLV90ZXh0ZGJsaHlwaGVuY2hhcg==", Symbol { command: "\\textdblhyphenchar", package: "textcomp", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX25zdXBzZXRlcXE=", Symbol { command: "\\nsupseteqq", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: None }),
        ("bGF0ZXgyZS1PVDEtX3VwZG93bmFycm93", Symbol { command: "\\updownarrow", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("arrow.t.b") }),
        ("YW1zc3ltYi1PVDEtX25nZXFzbGFudA==", Symbol { command: "\\ngeqslant", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("gt.eq.not") }),
        ("bGF0ZXgyZS1PVDEtX2RvdGVx", Symbol { command: "\\doteq", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("≐") }),
        ("YW1zc3ltYi1PVDEtX3JpZ2h0bGVmdGFycm93cw==", Symbol { command: "\\rightleftarrows", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("arrows.rl") }),
        ("bGF0ZXgyZS1PVDEtX3VwYXJyb3c=", Symbol { command: "\\uparrow", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("arrow.t") }),
        ("bGF0ZXgyZS1PVDEtX1VwZG93bmFycm93", Symbol { command: "\\Updownarrow", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("arrow.t.b.double") }),
        ("d2FzeXN5bS1PVDEtX3JoZA==", Symbol { command: "\\rhd", package: "wasysym", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("triangle.stroked.r") }),
        ("dGlwYS1PVDEtX3RleHRyaG9va3NjaHdh", Symbol { command: "\\textrhookschwa", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("ZHNmb250LU9UMS1fbWF0aGRze0Z9", Symbol { command: "\\mathds{F}", package: "dsfont", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.bb(F)") }),
        ("YW1zc3ltYi1PVDEtX21hdGhjYWx7VH0=", Symbol { command: "\\mathcal{T}", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.cal(T)") }),
        ("YW1zc3ltYi1PVDEtX21hdGhjYWx7Qn0=", Symbol { command: "\\mathcal{B}", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.cal(B)") }),
        ("bGF0ZXgyZS1PVDEtX2RpYW1vbmQ=", Symbol { command: "\\diamond", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("diamond.stroked.small") }),
        ("dGlwYS1PVDEtX3RleHRsaG9va3Q=", Symbol { command: "\\textlhookt", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("dGlwYS1PVDEtX3RleHR0dXJubXJsZWc=", Symbol { command: "\\textturnmrleg", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("bGF0ZXgyZS1PVDEtX2ltYXRo", Symbol { command: "\\imath", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("dotless.i") }),
        ("YW1zc3ltYi1PVDEtX2JveGRvdA==", Symbol { command: "\\boxdot", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("dot.square") }),
        ("YW1zc3ltYi1PVDEtX0dhbWU=", Symbol { command: "\\Game", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("⅁") }),
        ("dGlwYS1PVDEtX3RleHRlc2g=", Symbol { command: "\\textesh", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX3ZhcnRyaWFuZ2xl", Symbol { command: "\\vartriangle", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("triangle.stroked.small.t") }),
        ("bGF0ZXgyZS1UMS1fTkc=", Symbol { command: "\\NG", package: "latex2e", font_encoding: "T1", text_mode: true, math_mode: false, typst_command: None }),
        ("c3RtYXJ5cmQtT1QxLV9sbHBhcmVudGhlc2lz", Symbol { command: "\\llparenthesis", package: "stmaryrd", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("paren.l.closed") }),
        ("bGF0ZXgyZS1PVDEtX2N1cA==", Symbol { command: "\\cup", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("union") }),
        ("YW1zc3ltYi1PVDEtX3ZhcnRyaWFuZ2xlcmlnaHQ=", Symbol { command: "\\vartriangleright", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("gt.tri") }),
        ("YW1zc3ltYi1PVDEtX2FuZ2xl", Symbol { command: "\\angle", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("angle") }),
        ("dGlwYS1PVDEtX3RleHRycHRy", Symbol { command: "\\textrptr", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("dGlwYS1PVDEtX3RleHRsb25nbGVncg==", Symbol { command: "\\textlonglegr", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("bGF0ZXgyZS1PVDEtX2JpZ29wbHVz", Symbol { command: "\\bigoplus", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("xor.big") }),
        ("bGF0ZXgyZS1UMS1fZ3VpbGxlbW90bGVmdA==", Symbol { command: "\\guillemotleft", package: "latex2e", font_encoding: "T1", text_mode: true, math_mode: false, typst_command: None }),
        ("dXBncmVlay1PVDEtX3VwZ2FtbWE=", Symbol { command: "\\upgamma", package: "upgreek", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX2RpYWdkb3du", Symbol { command: "\\diagdown", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("╲") }),
        ("YW1zc3ltYi1PVDEtX25zdWNjZXE=", Symbol { command: "\\nsucceq", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("succ.eq.not") }),
        ("bGF0ZXgyZS1PVDEtX2RpYW1vbmRzdWl0", Symbol { command: "\\diamondsuit", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("suit.diamond.stroked") }),
        ("dGV4dGNvbXAtT1QxLV90ZXh0ZGlzY291bnQ=", Symbol { command: "\\textdiscount", package: "textcomp", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("d2FzeXN5bS1PVDEtX2ludmRpYW1ldGVy", Symbol { command: "\\invdiameter", package: "wasysym", font_encoding: "OT1", text_mode: true, math_mode: true, typst_command: None }),
        ("bGF0ZXgyZS1PVDEtX251", Symbol { command: "\\nu", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("nu") }),
        ("dGlwYS1PVDEtX3RleHRydGFpbGQ=", Symbol { command: "\\textrtaild", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX21hdGhmcmFre0t9", Symbol { command: "\\mathfrak{K}", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.frak(K)") }),
        ("bGF0ZXgyZS1PVDEtX3pldGE=", Symbol { command: "\\zeta", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("zeta") }),
        ("YW1zc3ltYi1PVDEtX25wcmVjZXE=", Symbol { command: "\\npreceq", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("prec.eq.not") }),
        ("bGF0ZXgyZS1PVDEtX2Nkb3Rz", Symbol { command: "\\cdots", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("dots.h.c") }),
        ("YW1zc3ltYi1PVDEtX2xuc2lt", Symbol { command: "\\lnsim", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("lt.ntilde") }),
        ("YW1zc3ltYi1PVDEtX21hdGhmcmFre2J9", Symbol { command: "\\mathfrak{b}", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.frak(b)") }),
        ("YW1zc3ltYi1PVDEtX2N1cmx5ZXFwcmVj", Symbol { command: "\\curlyeqprec", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("eq.prec") }),
        ("YW1zc3ltYi1PVDEtX3N1cHNldG5lcQ==", Symbol { command: "\\supsetneq", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("supset.neq") }),
        ("bGF0ZXgyZS1PVDEtX3RleHRzdGVybGluZw==", Symbol { command: "\\textsterling", package: "latex2e", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: Some("pound") }),
        ("dGlwYS1PVDEtX3RleHRiZXRh", Symbol { command: "\\textbeta", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("bWFydm9zeW0tT1QxLV9NZXJjdXJ5", Symbol { command: "\\Mercury", package: "marvosym", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("dGV4dGNvbXAtT1QxLV90ZXh0bGlyYQ==", Symbol { command: "\\textlira", package: "textcomp", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("ZHNmb250LU9UMS1fbWF0aGRze1V9", Symbol { command: "\\mathds{U}", package: "dsfont", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.bb(U)") }),
        ("YW1zc3ltYi1PVDEtX2duc2lt", Symbol { command: "\\gnsim", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("gt.ntilde") }),
        ("dGlwYS1PVDEtX3RleHRydGFpbHI=", Symbol { command: "\\textrtailr", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("dGV4dGNvbXAtT1QxLV90ZXh0bWludXM=", Symbol { command: "\\textminus", package: "textcomp", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("bWFydm9zeW0tT1QxLV9FY29tbWVyY2U=", Symbol { command: "\\Ecommerce", package: "marvosym", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX25sZWZ0YXJyb3c=", Symbol { command: "\\nleftarrow", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("arrow.l.not") }),
        ("bGF0ZXgyZS1PVDEtX2hiYXI=", Symbol { command: "\\hbar", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("planck.reduce") }),
        ("dGV4dGNvbXAtT1QxLV90ZXh0bG5vdA==", Symbol { command: "\\textlnot", package: "textcomp", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("dXBncmVlay1PVDEtX3VwcGhp", Symbol { command: "\\upphi", package: "upgreek", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: None }),
        ("dXBncmVlay1PVDEtX1VwdXBzaWxvbg==", Symbol { command: "\\Upupsilon", package: "upgreek", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: None }),
        ("YW1zbWF0aC1PVDEtX2lkb3RzaW50", Symbol { command: "\\idotsint", package: "amsmath", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: None }),
        ("dGV4dGNvbXAtT1QxLV90ZXh0cGVyaW9kY2VudGVyZWQ=", Symbol { command: "\\textperiodcentered", package: "textcomp", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("bGF0ZXgyZS1PVDEtX3RleHR1bmRlcnNjb3Jl", Symbol { command: "\\textunderscore", package: "latex2e", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: Some("\\_") }),
        ("dGlwYS1PVDEtX3RleHRzY2k=", Symbol { command: "\\textsci", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("dGlwYS1PVDEtX3RleHRjcmc=", Symbol { command: "\\textcrg", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("ZXNpbnQtT1QxLV9paW50", Symbol { command: "\\iint", package: "esint", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("integral.double") }),
        ("YW1zc3ltYi1PVDEtX21hdGhiYntPfQ==", Symbol { command: "\\mathbb{O}", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: None }),
        ("bGF0ZXgyZS1PVDEtX3RleHRicmFjZXJpZ2h0", Symbol { command: "\\textbraceright", package: "latex2e", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: Some("}") }),
        ("ZHNmb250LU9UMS1fbWF0aGRze0J9", Symbol { command: "\\mathds{B}", package: "dsfont", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.bb(B)") }),
        ("YW1zc3ltYi1PVDEtX3VwaGFycG9vbmxlZnQ=", Symbol { command: "\\upharpoonleft", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("harpoon.tl") }),
        ("bWFydm9zeW0tT1QxLV9UYXVydXM=", Symbol { command: "\\Taurus", package: "marvosym", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX3VwaGFycG9vbnJpZ2h0", Symbol { command: "\\upharpoonright", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("harpoon.tr") }),
        ("dGlwYS1PVDEtX3RleHRn", Symbol { command: "\\textg", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("d2FzeXN5bS1PVDEtX2Nvbmp1bmN0aW9u", Symbol { command: "\\conjunction", package: "wasysym", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("bGF0ZXgyZS1PVDEtX2Rpdg==", Symbol { command: "\\div", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("div") }),
        ("bGF0ZXgyZS1PVDEtX2VtcHR5c2V0", Symbol { command: "\\emptyset", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("nothing") }),
        ("bGF0ZXgyZS1PVDEtX3JjZWls", Symbol { command: "\\rceil", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("ceil.r") }),
        ("YW1zc3ltYi1PVDEtX2xlcQ==", Symbol { command: "\\leq", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("lt.eq") }),
        ("bGF0ZXgyZS1PVDEtX2ZsYXQ=", Symbol { command: "\\flat", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("flat") }),
        ("bWF0aHJzZnMtT1QxLV9tYXRoc2Nye0Z9", Symbol { command: "\\mathscr{F}", package: "mathrsfs", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.scr(F)") }),
        ("d2FzeXN5bS1PVDEtX2xlZnRtb29u", Symbol { command: "\\leftmoon", package: "wasysym", font_encoding: "OT1", text_mode: true, math_mode: true, typst_command: None }),
        ("dXBncmVlay1PVDEtX3VwaW90YQ==", Symbol { command: "\\upiota", package: "upgreek", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: None }),
        ("YW1zbWF0aC1PVDEtX2RvdHNv", Symbol { command: "\\dotso", package: "amsmath", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("dots.h") }),
        ("dGV4dGNvbXAtT1QxLV90ZXh0b3JkbWFzY3VsaW5l", Symbol { command: "\\textordmasculine", package: "textcomp", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("bGF0ZXgyZS1PVDEtX3JpZ2h0bGVmdGhhcnBvb25z", Symbol { command: "\\rightleftharpoons", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("harpoons.rtlb") }),
        ("bGF0ZXgyZS1PVDEtX0lt", Symbol { command: "\\Im", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("Im") }),
        ("YW1zc3ltYi1PVDEtX2JhY2twcmltZQ==", Symbol { command: "\\backprime", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("prime.rev") }),
        ("YW1zc3ltYi1PVDEtX21hdGhiYntJfQ==", Symbol { command: "\\mathbb{I}", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: None }),
        ("dGlwYS1PVDEtX3RleHRiYXJv", Symbol { command: "\\textbaro", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX2JlY2F1c2U=", Symbol { command: "\\because", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("because") }),
        ("YW1zc3ltYi1PVDEtX21hdGhjYWx7Un0=", Symbol { command: "\\mathcal{R}", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.cal(R)") }),
        ("dGV4dGNvbXAtT1QxLV90ZXh0cmFuZ2xl", Symbol { command: "\\textrangle", package: "textcomp", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("bGF0ZXgyZS1PVDEtX25vdF9lcXVpdg==", Symbol { command: "\\not\\equiv", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: None }),
        ("d2FzeXN5bS1PVDEtX25lcHR1bmU=", Symbol { command: "\\neptune", package: "wasysym", font_encoding: "OT1", text_mode: true, math_mode: true, typst_command: None }),
        ("dGV4dGNvbXAtT1QxLV90ZXh0cmVjaXBl", Symbol { command: "\\textrecipe", package: "textcomp", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("bGF0ZXgyZS1PVDEtX3Zkb3Rz", Symbol { command: "\\vdots", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("dots.v") }),
        ("bWFydm9zeW0tT1QxLV9MZW8=", Symbol { command: "\\Leo", package: "marvosym", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("bGF0ZXgyZS1PVDEtX3RleHRidWxsZXQ=", Symbol { command: "\\textbullet", package: "latex2e", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("d2FzeXN5bS1PVDEtX3Zpcmdv", Symbol { command: "\\virgo", package: "wasysym", font_encoding: "OT1", text_mode: true, math_mode: true, typst_command: None }),
        ("d2FzeXN5bS1PVDEtX3Njb3JwaW8=", Symbol { command: "\\scorpio", package: "wasysym", font_encoding: "OT1", text_mode: true, math_mode: true, typst_command: None }),
        ("bGF0ZXgyZS1PVDEtX3RleHRxdW90ZWRibGxlZnQ=", Symbol { command: "\\textquotedblleft", package: "latex2e", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: Some("quote.l.double") }),
        ("dGlwYS1PVDEtX3RleHRzY3JpcHRn", Symbol { command: "\\textscriptg", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX0JiYms=", Symbol { command: "\\Bbbk", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: None }),
        ("bGF0ZXgyZS1PVDEtX21hdGhzdGVybGluZw==", Symbol { command: "\\mathsterling", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("pound") }),
        ("ZHNmb250LU9UMS1fbWF0aGRze0l9", Symbol { command: "\\mathds{I}", package: "dsfont", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.bb(I)") }),
        ("bGF0ZXgyZS1PVDEtX1BoaQ==", Symbol { command: "\\Phi", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("Phi") }),
        ("YW1zc3ltYi1PVDEtX3RoZXJlZm9yZQ==", Symbol { command: "\\therefore", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("therefore") }),
        ("YW1zc3ltYi1PVDEtX21hdGhiYntLfQ==", Symbol { command: "\\mathbb{K}", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: None }),
        ("bWFydm9zeW0tT1QxLV9WZW51cw==", Symbol { command: "\\Venus", package: "marvosym", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("dGlwYS1PVDEtX3RleHRkb3VibGV2ZXJ0bGluZQ==", Symbol { command: "\\textdoublevertline", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("YW1zbWF0aC1PVDEtX2lpaW50", Symbol { command: "\\iiint", package: "amsmath", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("integral.triple") }),
        ("bGF0ZXgyZS1PVDEtX2JpZ3dlZGdl", Symbol { command: "\\bigwedge", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("and.big") }),
        ("bGF0ZXgyZS1PVDEtX3RleHRxdW90ZWRibHJpZ2h0", Symbol { command: "\\textquotedblright", package: "latex2e", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: Some("quote.r.double") }),
        ("dGlwYS1PVDEtX3RleHRodGhlbmc=", Symbol { command: "\\texththeng", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("dXBncmVlay1PVDEtX1VwbGFtYmRh", Symbol { command: "\\Uplambda", package: "upgreek", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: None }),
        ("bGF0ZXgyZS1PVDEtX2Fl", Symbol { command: "\\ae", package: "latex2e", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: Some("æ") }),
        ("bGF0ZXgyZS1PVDEtX3RleHRvcmRtYXNjdWxpbmU=", Symbol { command: "\\textordmasculine", package: "latex2e", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("bGF0ZXgyZS1PVDEtX29zbGFzaA==", Symbol { command: "\\oslash", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("slash.o") }),
        ("dGlwYS1PVDEtX3RleHRsdGFpbG0=", Symbol { command: "\\textltailm", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("bGF0ZXgyZS1PVDEtX1VwYXJyb3c=", Symbol { command: "\\Uparrow", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("arrow.t.double") }),
        ("YW1zc3ltYi1PVDEtX3ByZWNzaW0=", Symbol { command: "\\precsim", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("prec.tilde") }),
        ("dXBncmVlay1PVDEtX3Vwc2lnbWE=", Symbol { command: "\\upsigma", package: "upgreek", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: None }),
        ("dXBncmVlay1PVDEtX3Vwb21lZ2E=", Symbol { command: "\\upomega", package: "upgreek", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX21hdGhjYWx7Rn0=", Symbol { command: "\\mathcal{F}", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.cal(F)") }),
        ("d2FzeXN5bS1PVDEtX3JlY29yZGVy", Symbol { command: "\\recorder", package: "wasysym", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("bGF0ZXgyZS1PVDEtX2JpZ2NpcmM=", Symbol { command: "\\bigcirc", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("circle.stroked.big") }),
        ("bGF0ZXgyZS1PVDEtX3N1cHNldGVx", Symbol { command: "\\supseteq", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("supset.eq") }),
        ("dGlwYS1PVDEtX3RleHRoYXJkc2lnbg==", Symbol { command: "\\texthardsign", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX2NpcmNsZWRT", Symbol { command: "\\circledS", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("Ⓢ") }),
        ("bGF0ZXgyZS1PVDEtX1Bp", Symbol { command: "\\Pi", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("Pi") }),
        ("YW1zc3ltYi1PVDEtX21hdGhiYntTfQ==", Symbol { command: "\\mathbb{S}", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: None }),
        ("dGV4dGNvbXAtT1QxLV90ZXh0d29u", Symbol { command: "\\textwon", package: "textcomp", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("bGF0ZXgyZS1PVDEtX3RleHRhc3Rlcmlza2NlbnRlcmVk", Symbol { command: "\\textasteriskcentered", package: "latex2e", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("bGF0ZXgyZS1PVDEtX3RleHRncmVhdGVy", Symbol { command: "\\textgreater", package: "latex2e", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: Some("gt") }),
        ("dGlwYS1PVDEtX3RleHRyZXZ5b2do", Symbol { command: "\\textrevyogh", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX21hdGhjYWx7T30=", Symbol { command: "\\mathcal{O}", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.cal(O)") }),
        ("c3RtYXJ5cmQtT1QxLV9sbGJyYWNrZXQ=", Symbol { command: "\\llbracket", package: "stmaryrd", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("bracket.l.double") }),
        ("d2FzeXN5bS1PVDEtX2p1cGl0ZXI=", Symbol { command: "\\jupiter", package: "wasysym", font_encoding: "OT1", text_mode: true, math_mode: true, typst_command: None }),
        ("dGV4dGNvbXAtT1QxLV90ZXh0ZGJsaHlwaGVu", Symbol { command: "\\textdblhyphen", package: "textcomp", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("bGF0ZXgyZS1UMS1fZ3VpbHNpbmdscmlnaHQ=", Symbol { command: "\\guilsinglright", package: "latex2e", font_encoding: "T1", text_mode: true, math_mode: false, typst_command: None }),
        ("c3RtYXJ5cmQtT1QxLV9sb25nbWFwc2Zyb20=", Symbol { command: "\\longmapsfrom", package: "stmaryrd", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("arrow.l.long.bar") }),
        ("YW1zc3ltYi1PVDEtX2NpcmNsZWRkYXNo", Symbol { command: "\\circleddash", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("dash.circle") }),
        ("dGV4dGNvbXAtT1QxLV90ZXh0cmJyYWNrZGJs", Symbol { command: "\\textrbrackdbl", package: "textcomp", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX21hdGhmcmFre3N9", Symbol { command: "\\mathfrak{s}", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.frak(s)") }),
        ("YW1zc3ltYi1PVDEtX25MZWZ0YXJyb3c=", Symbol { command: "\\nLeftarrow", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("arrow.l.double.not") }),
        ("bGF0ZXgyZS1PVDEtX0xvbmdsZWZ0YXJyb3c=", Symbol { command: "\\Longleftarrow", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("arrow.l.double.long") }),
        ("dGlwYS1PVDEtX3RleHR0b25lbGV0dGVyc3RlbQ==", Symbol { command: "\\texttoneletterstem", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX25zaG9ydG1pZA==", Symbol { command: "\\nshortmid", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: None }),
        ("c3RtYXJ5cmQtT1QxLV9sZWZ0YXJyb3d0cmlhbmdsZQ==", Symbol { command: "\\leftarrowtriangle", package: "stmaryrd", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("arrow.l.open") }),
        ("c2t1bGwtT1QxLV9za3VsbA==", Symbol { command: "\\skull", package: "skull", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX3JpZ2h0c3F1aWdhcnJvdw==", Symbol { command: "\\rightsquigarrow", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("arrow.r.squiggly") }),
        ("bWFydm9zeW0tT1QxLV9FYXJ0aA==", Symbol { command: "\\Earth", package: "marvosym", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("dGlwYS1PVDEtX3RleHRodmxpZw==", Symbol { command: "\\texthvlig", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX2JsYWNrc3F1YXJl", Symbol { command: "\\blacksquare", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("qed") }),
        ("bGF0ZXgyZS1PVDEtX1Vwc2lsb24=", Symbol { command: "\\Upsilon", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("Upsilon") }),
        ("c3RtYXJ5cmQtT1QxLV9NYXBzdG8=", Symbol { command: "\\Mapsto", package: "stmaryrd", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("arrow.r.double.bar") }),
        ("dGlwYS1PVDEtX3RleHRwaXBl", Symbol { command: "\\textpipe", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("d2FzeXN5bS1PVDEtX2VhcnRo", Symbol { command: "\\earth", package: "wasysym", font_encoding: "OT1", text_mode: true, math_mode: true, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX2JveHRpbWVz", Symbol { command: "\\boxtimes", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("times.square") }),
        ("dGV4dGNvbXAtT1QxLV90ZXh0cXVvdGVzdHJhaWdodGRibGJhc2U=", Symbol { command: "\\textquotestraightdblbase", package: "textcomp", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX2dlcQ==", Symbol { command: "\\geq", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("gt.eq") }),
        ("dGV4dGNvbXAtT1QxLV90ZXh0Zmxvcmlu", Symbol { command: "\\textflorin", package: "textcomp", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX3ZhcnN1cHNldG5lcXE=", Symbol { command: "\\varsupsetneqq", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("⫌") }),
        ("bGF0ZXgyZS1PVDEtX3s=", Symbol { command: "\\{", package: "latex2e", font_encoding: "OT1", text_mode: true, math_mode: true, typst_command: Some("\\{") }),
        ("YW1zc3ltYi1PVDEtX21hdGhmcmFre1d9", Symbol { command: "\\mathfrak{W}", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.frak(W)") }),
        ("YW1zc3ltYi1PVDEtX21hdGhmcmFre2t9", Symbol { command: "\\mathfrak{k}", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.frak(k)") }),
        ("d2FzeXN5bS1PVDEtX2FzY25vZGU=", Symbol { command: "\\ascnode", package: "wasysym", font_encoding: "OT1", text_mode: true, math_mode: true, typst_command: None }),
        ("bWFydm9zeW0tT1QxLV9WaXJnbw==", Symbol { command: "\\Virgo", package: "marvosym", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("dGlwYS1PVDEtX3RleHRkeW9naGxpZw==", Symbol { command: "\\textdyoghlig", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("bGF0ZXgyZS1PVDEtX2FzeW1w", Symbol { command: "\\asymp", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("asymp") }),
        ("YW1zc3ltYi1PVDEtX2JhY2tzaW0=", Symbol { command: "\\backsim", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("tilde.rev") }),
        ("YW1zc3ltYi1PVDEtX2d0cmVxcWxlc3M=", Symbol { command: "\\gtreqqless", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX25leGlzdHM=", Symbol { command: "\\nexists", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("exists.not") }),
        ("d2FzeXN5bS1PVDEtX2tyZXV6", Symbol { command: "\\kreuz", package: "wasysym", font_encoding: "OT1", text_mode: true, math_mode: true, typst_command: None }),
        ("ZXNpbnQtT1QxLV9vaW50Y2xvY2t3aXNl", Symbol { command: "\\ointclockwise", package: "esint", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: None }),
        ("dGlwYS1PVDEtX3RleHRodGI=", Symbol { command: "\\texthtb", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("bGF0ZXgyZS1PVDEtX3JhbmdsZQ==", Symbol { command: "\\rangle", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("chevron.r") }),
        ("dGV4dGNvbXAtT1QxLV90ZXh0Y29weXJpZ2h0", Symbol { command: "\\textcopyright", package: "textcomp", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("bGF0ZXgyZS1PVDEtX2VxdWl2", Symbol { command: "\\equiv", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("equiv") }),
        ("d2FzeXN5bS1PVDEtX2F0YXJpYm94", Symbol { command: "\\ataribox", package: "wasysym", font_encoding: "OT1", text_mode: true, math_mode: true, typst_command: None }),
        ("dXBncmVlay1PVDEtX3VwdmFyc2lnbWE=", Symbol { command: "\\upvarsigma", package: "upgreek", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: None }),
        ("dGlwYS1PVDEtX3RleHRzY29lbGln", Symbol { command: "\\textscoelig", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("bGF0ZXgyZS1PVDEtX3BvdW5kcw==", Symbol { command: "\\pounds", package: "latex2e", font_encoding: "OT1", text_mode: true, math_mode: true, typst_command: Some("pound") }),
        ("bGF0ZXgyZS1PVDEtX3RleHR0cmFkZW1hcms=", Symbol { command: "\\texttrademark", package: "latex2e", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("dGV4dGNvbXAtT1QxLV90ZXh0Y3VycmVuY3k=", Symbol { command: "\\textcurrency", package: "textcomp", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("dGlwYS1PVDEtX3RleHRodHA=", Symbol { command: "\\texthtp", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("dGV4dGNvbXAtT1QxLV90ZXh0YXN0ZXJpc2tjZW50ZXJlZA==", Symbol { command: "\\textasteriskcentered", package: "textcomp", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("bGF0ZXgyZS1PVDEtX21pZA==", Symbol { command: "\\mid", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("divides") }),
        ("bGF0ZXgyZS1PVDEtX29pbnQ=", Symbol { command: "\\oint", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("integral.cont") }),
        ("YW1zc3ltYi1PVDEtX25WRGFzaA==", Symbol { command: "\\nVDash", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("⊯") }),
        ("YW1zc3ltYi1PVDEtX2xlc3NzaW0=", Symbol { command: "\\lesssim", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("lt.tilde") }),
        ("bWF0aHJzZnMtT1QxLV9tYXRoc2Nye0F9", Symbol { command: "\\mathscr{A}", package: "mathrsfs", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.scr(A)") }),
        ("YW1zc3ltYi1PVDEtX21hdGhiYntQfQ==", Symbol { command: "\\mathbb{P}", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: None }),
        ("dGV4dGNvbXAtT1QxLV90ZXh0Y29sb25tb25ldGFyeQ==", Symbol { command: "\\textcolonmonetary", package: "textcomp", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("bGF0ZXgyZS1PVDEtX3ZkYXNo", Symbol { command: "\\vdash", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("tack.r") }),
        ("YW1zc3ltYi1PVDEtX21hdGhmcmFre0R9", Symbol { command: "\\mathfrak{D}", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.frak(D)") }),
        ("dGlwYS1PVDEtX3RleHRyaG90aWNpdHk=", Symbol { command: "\\textrhoticity", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX252RGFzaA==", Symbol { command: "\\nvDash", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("tack.r.double.not") }),
        ("d2FzeXN5bS1PVDEtX3RhdXJ1cw==", Symbol { command: "\\taurus", package: "wasysym", font_encoding: "OT1", text_mode: true, math_mode: true, typst_command: None }),
        ("bGF0ZXgyZS1PVDEtX2xkb3Rz", Symbol { command: "\\ldots", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("dots.h") }),
        ("YW1zc3ltYi1PVDEtX21hdGhmcmFre3h9", Symbol { command: "\\mathfrak{x}", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.frak(x)") }),
        ("YW1zc3ltYi1PVDEtX2xlZnRsZWZ0YXJyb3dz", Symbol { command: "\\leftleftarrows", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("arrows.ll") }),
        ("dXBncmVlay1PVDEtX3VwdmFycmhv", Symbol { command: "\\upvarrho", package: "upgreek", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX3ByZWNjdXJseWVx", Symbol { command: "\\preccurlyeq", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("prec.curly.eq") }),
        ("YW1zc3ltYi1PVDEtX2xlc3NhcHByb3g=", Symbol { command: "\\lessapprox", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("lt.approx") }),
        ("dGlwYS1PVDEtX3RleHRzY2o=", Symbol { command: "\\textscj", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX2RpYWd1cA==", Symbol { command: "\\diagup", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("╱") }),
        ("dGV4dGNvbXAtT1QxLV90ZXh0ZG9sbGFyb2xkc3R5bGU=", Symbol { command: "\\textdollaroldstyle", package: "textcomp", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX21hdGhiYntWfQ==", Symbol { command: "\\mathbb{V}", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: None }),
        ("bGF0ZXgyZS1PVDEtX3JpZ2h0aGFycG9vbmRvd24=", Symbol { command: "\\rightharpoondown", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("harpoon.rb") }),
        ("dGlwYS1PVDEtX3RleHRscHRy", Symbol { command: "\\textlptr", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("c3RtYXJ5cmQtT1QxLV9ycmZsb29y", Symbol { command: "\\rrfloor", package: "stmaryrd", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX3N1cHNldG5lcXE=", Symbol { command: "\\supsetneqq", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("⫌") }),
        ("bGF0ZXgyZS1PVDEtX3RleHRhc2NpaXRpbGRl", Symbol { command: "\\textasciitilde", package: "latex2e", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: Some("~") }),
        ("bWFydm9zeW0tT1QxLV9FeWVzRG9sbGFy", Symbol { command: "\\EyesDollar", package: "marvosym", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX3RoaWNrc2lt", Symbol { command: "\\thicksim", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("thicksim") }),
        ("YW1zc3ltYi1PVDEtX2N1cmx5ZXFzdWNj", Symbol { command: "\\curlyeqsucc", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("eq.succ") }),
        ("d2FzeXN5bS1PVDEtX2Nsb2Nr", Symbol { command: "\\clock", package: "wasysym", font_encoding: "OT1", text_mode: true, math_mode: true, typst_command: None }),
        ("dGlwYS1PVDEtX3RleHR0dXJudg==", Symbol { command: "\\textturnv", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("dGV4dGNvbXAtT1QxLV90ZXh0ZG9uZw==", Symbol { command: "\\textdong", package: "textcomp", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("dGlwYS1PVDEtX3RleHRzdHJldGNoYw==", Symbol { command: "\\textstretchc", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX1Z2ZGFzaA==", Symbol { command: "\\Vvdash", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("⊪") }),
        ("bGF0ZXgyZS1PVDEtX2xvbmdsZWZ0YXJyb3c=", Symbol { command: "\\longleftarrow", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("arrow.l.long") }),
        ("YW1zc3ltYi1PVDEtX250cmlhbmdsZXJpZ2h0ZXE=", Symbol { command: "\\ntrianglerighteq", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("gt.tri.eq.not") }),
        ("bWFydm9zeW0tT1QxLV9Dcm9zcw==", Symbol { command: "\\Cross", package: "marvosym", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("d2FzeXN5bS1PVDEtX2ZlbWFsZQ==", Symbol { command: "\\female", package: "wasysym", font_encoding: "OT1", text_mode: true, math_mode: true, typst_command: None }),
        ("bGF0ZXgyZS1PVDEtX2Vwc2lsb24=", Symbol { command: "\\epsilon", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("epsilon.alt") }),
        ("bGF0ZXgyZS1PVDEtX0FF", Symbol { command: "\\AE", package: "latex2e", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: Some("Æ") }),
        ("bGF0ZXgyZS1PVDEtX21w", Symbol { command: "\\mp", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("minus.plus") }),
        ("bGF0ZXgyZS1PVDEtX1NpZ21h", Symbol { command: "\\Sigma", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("Sigma") }),
        ("d2FzeXN5bS1PVDEtX21hbGU=", Symbol { command: "\\male", package: "wasysym", font_encoding: "OT1", text_mode: true, math_mode: true, typst_command: None }),
        ("dGV4dGNvbXAtT1QxLV90ZXh0bnVtZXJv", Symbol { command: "\\textnumero", package: "textcomp", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("bGF0ZXgyZS1PVDEtX21vZGVscw==", Symbol { command: "\\models", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("models") }),
        ("bGF0ZXgyZS1PVDEtX08=", Symbol { command: "\\O", package: "latex2e", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: Some("nothing") }),
        ("YW1zc3ltYi1PVDEtX3NwaGVyaWNhbGFuZ2xl", Symbol { command: "\\sphericalangle", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("angle.spheric") }),
        ("c3RtYXJ5cmQtT1QxLV9zaG9ydGRvd25hcnJvdw==", Symbol { command: "\\shortdownarrow", package: "stmaryrd", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: None }),
        ("dXBncmVlay1PVDEtX3VwdmFycGk=", Symbol { command: "\\upvarpi", package: "upgreek", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX2J1bXBlcQ==", Symbol { command: "\\bumpeq", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("≏") }),
        ("bGF0ZXgyZS1PVDEtX253YXJyb3c=", Symbol { command: "\\nwarrow", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("arrow.tl") }),
        ("ZHNmb250LU9UMS1fbWF0aGRze1R9", Symbol { command: "\\mathds{T}", package: "dsfont", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.bb(T)") }),
        ("YW1zc3ltYi1PVDEtX2JveG1pbnVz", Symbol { command: "\\boxminus", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("minus.square") }),
        ("YW1zc3ltYi1PVDEtX3NtYWxsc2V0bWludXM=", Symbol { command: "\\smallsetminus", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("without") }),
        ("bWFydm9zeW0tT1QxLV9UZWxlZm9u", Symbol { command: "\\Telefon", package: "marvosym", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("bWF0aHJzZnMtT1QxLV9tYXRoc2Nye1p9", Symbol { command: "\\mathscr{Z}", package: "mathrsfs", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.scr(Z)") }),
        ("YW1zbWF0aC1PVDEtX2RvdHNj", Symbol { command: "\\dotsc", package: "amsmath", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("dots.h") }),
        ("dGlwYS1PVDEtX3RleHRPYmFyZG90bGVzc2o=", Symbol { command: "\\textObardotlessj", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX3JpZ2h0cmlnaHRhcnJvd3M=", Symbol { command: "\\rightrightarrows", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("arrows.rr") }),
        ("dXBncmVlay1PVDEtX3VwdmFycGhp", Symbol { command: "\\upvarphi", package: "upgreek", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: None }),
        ("dGlwYS1PVDEtX3RleHRjaGk=", Symbol { command: "\\textchi", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("dGlwYS1PVDEtX3RleHRzY2U=", Symbol { command: "\\textsce", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("bGF0ZXgyZS1PVDEtX3RvcA==", Symbol { command: "\\top", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("top") }),
        ("YW1zc3ltYi1PVDEtX21hdGhjYWx7Q30=", Symbol { command: "\\mathcal{C}", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.cal(C)") }),
        ("bGF0ZXgyZS1PVDEtX3NpZ21h", Symbol { command: "\\sigma", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("sigma") }),
        ("dGlwYS1PVDEtX3RleHRyYWlzZXZpYnlp", Symbol { command: "\\textraisevibyi", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("dGlwYS1PVDEtX3RleHRiYXJn", Symbol { command: "\\textbarg", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("dGlwYS1PVDEtX3RleHRyYWlzZWdsb3RzdG9w", Symbol { command: "\\textraiseglotstop", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("dXBncmVlay1PVDEtX1VwcHNp", Symbol { command: "\\Uppsi", package: "upgreek", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX21hdGhjYWx7SH0=", Symbol { command: "\\mathcal{H}", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.cal(H)") }),
        ("bGF0ZXgyZS1PVDEtX3N1bQ==", Symbol { command: "\\sum", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("sum") }),
        ("YW1zc3ltYi1PVDEtX3ZhcmthcHBh", Symbol { command: "\\varkappa", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("kappa.alt") }),
        ("dGlwYS1PVDEtX3RleHRpbnZnbG90c3RvcA==", Symbol { command: "\\textinvglotstop", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("dGlwYS1PVDEtX3RleHRiYXJk", Symbol { command: "\\textbard", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("ZHNmb250LU9UMS1fbWF0aGRze1p9", Symbol { command: "\\mathds{Z}", package: "dsfont", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.bb(Z)") }),
        ("dGlwYS1PVDEtX3RleHRzY3U=", Symbol { command: "\\textscu", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("dGlwYS1PVDEtX3RleHRpb3Rh", Symbol { command: "\\textiota", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("d2FzeXN5bS1PVDEtX3Blcm1pbA==", Symbol { command: "\\permil", package: "wasysym", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("ZXNpbnQtT1QxLV9sYW5kdXBpbnQ=", Symbol { command: "\\landupint", package: "esint", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: None }),
        ("bWFydm9zeW0tT1QxLV9GQVg=", Symbol { command: "\\FAX", package: "marvosym", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX21hdGhmcmFre0x9", Symbol { command: "\\mathfrak{L}", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.frak(L)") }),
        ("YW1zc3ltYi1PVDEtX21hdGhmcmFre3Z9", Symbol { command: "\\mathfrak{v}", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.frak(v)") }),
        ("dGV4dGNvbXAtT1QxLV90ZXh0bGJyYWNrZGJs", Symbol { command: "\\textlbrackdbl", package: "textcomp", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX21hdGhiYntYfQ==", Symbol { command: "\\mathbb{X}", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: None }),
        ("d2FzeXN5bS1PVDEtX3BvaW50ZXI=", Symbol { command: "\\pointer", package: "wasysym", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("dXBncmVlay1PVDEtX3VwYmV0YQ==", Symbol { command: "\\upbeta", package: "upgreek", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: None }),
        ("dGlwYS1PVDEtX3RleHR0dXJubG9uZ2xlZ3I=", Symbol { command: "\\textturnlonglegr", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("bGF0ZXgyZS1PVDEtX2xhbmdsZQ==", Symbol { command: "\\langle", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("chevron.l") }),
        ("dGV4dGNvbXAtT1QxLV90ZXh0dGltZXM=", Symbol { command: "\\texttimes", package: "textcomp", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("dGV4dGNvbXAtT1QxLV90ZXh0dHdvc3VwZXJpb3I=", Symbol { command: "\\texttwosuperior", package: "textcomp", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX2NpcmNsZWRhc3Q=", Symbol { command: "\\circledast", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("convolve.o") }),
        ("YW1zc3ltYi1PVDEtX21hdGhiYntHfQ==", Symbol { command: "\\mathbb{G}", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: None }),
        ("dXBncmVlay1PVDEtX3Vwcmhv", Symbol { command: "\\uprho", package: "upgreek", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: None }),
        ("dGlwYS1PVDEtX3RleHRydGFpbG4=", Symbol { command: "\\textrtailn", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("ZHNmb250LU9UMS1fbWF0aGRze0d9", Symbol { command: "\\mathds{G}", package: "dsfont", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.bb(G)") }),
        ("bGF0ZXgyZS1PVDEtX2Nkb3Q=", Symbol { command: "\\cdot", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("dot.op") }),
        ("ZHNmb250LU9UMS1fbWF0aGRze0F9", Symbol { command: "\\mathds{A}", package: "dsfont", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.bb(A)") }),
        ("d2FzeXN5bS1PVDEtX3N1bg==", Symbol { command: "\\sun", package: "wasysym", font_encoding: "OT1", text_mode: true, math_mode: true, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX3Nxc3Vic2V0", Symbol { command: "\\sqsubset", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("subset.sq") }),
        ("YW1zc3ltYi1PVDEtX21hdGhiYntKfQ==", Symbol { command: "\\mathbb{J}", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX21hdGhmcmFre2V9", Symbol { command: "\\mathfrak{e}", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.frak(e)") }),
        ("bWF0aHJzZnMtT1QxLV9tYXRoc2Nye1l9", Symbol { command: "\\mathscr{Y}", package: "mathrsfs", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("math.scr(Y)") }),
        ("YW1zc3ltYi1PVDEtX3N1Y2Nuc2lt", Symbol { command: "\\succnsim", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("succ.ntilde") }),
        ("dGlwYS1PVDEtX3RleHRkemxpZw==", Symbol { command: "\\textdzlig", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("bWFydm9zeW0tT1QxLV9FVVJodg==", Symbol { command: "\\EURhv", package: "marvosym", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("bGF0ZXgyZS1PVDEtX3RleHRicmFjZWxlZnQ=", Symbol { command: "\\textbraceleft", package: "latex2e", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: Some("{") }),
        ("YW1zc3ltYi1PVDEtX2d0cnNpbQ==", Symbol { command: "\\gtrsim", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("gt.tilde") }),
        ("dGlwYS1PVDEtX3RleHRjcmg=", Symbol { command: "\\textcrh", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("bWFydm9zeW0tT1QxLV9TdW4=", Symbol { command: "\\Sun", package: "marvosym", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("YW1zc3ltYi1PVDEtX2x0aW1lcw==", Symbol { command: "\\ltimes", package: "amssymb", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("times.l") }),
        ("d2FzeXN5bS1PVDEtX1VQYXJyb3c=", Symbol { command: "\\UParrow", package: "wasysym", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("bGF0ZXgyZS1PVDEtX3ZlZQ==", Symbol { command: "\\vee", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("or") }),
        ("bWFydm9zeW0tT1QxLV9DaXJjbGVkQQ==", Symbol { command: "\\CircledA", package: "marvosym", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("c3RtYXJ5cmQtT1QxLV9saWdodG5pbmc=", Symbol { command: "\\lightning", package: "stmaryrd", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: None }),
        ("bGF0ZXgyZS1PVDEtX2RlbHRh", Symbol { command: "\\delta", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("delta") }),
        ("bGF0ZXgyZS1PVDEtX3Byb3B0bw==", Symbol { command: "\\propto", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("prop") }),
        ("bWFydm9zeW0tT1QxLV9QbHV0bw==", Symbol { command: "\\Pluto", package: "marvosym", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("bWFydm9zeW0tT1QxLV9TYXR1cm4=", Symbol { command: "\\Saturn", package: "marvosym", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("dGlwYS1PVDEtX3RleHRkb3VibGViYXJlc2g=", Symbol { command: "\\textdoublebaresh", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
        ("bGF0ZXgyZS1PVDEtX290aW1lcw==", Symbol { command: "\\otimes", package: "latex2e", font_encoding: "OT1", text_mode: false, math_mode: true, typst_command: Some("times.circle") }),
        ("dGlwYS1PVDEtX3RleHRyZXZnbG90c3RvcA==", Symbol { command: "\\textrevglotstop", package: "tipa", font_encoding: "OT1", text_mode: true, math_mode: false, typst_command: None }),
    ],
};
